"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtOpenGL import *
import enum


class QOpenGLTexture(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qopengltexture.html

    **Detailed Description**

    QOpenGLTexture makes it easy to work with OpenGL textures and the myriad
    features and targets that they offer depending upon the capabilities of your
    OpenGL implementation.

    The typical usage pattern for QOpenGLTexture is

    * Instantiate the object specifying the texture target type
      * Set
    properties that affect the storage requirements e.g. storage format,
    dimensions
      * Allocate the server-side storage
      * Optionally upload pixel
    data
      * Optionally set any additional properties e.g. filtering and border
    options
      * Render with texture or render to texture

    In the common case of simply using a **QImage**  as the source of texture
    pixel data most of the above steps are performed automatically.

    // Prepare texture
        **QOpenGLTexture**  *texture = new **QOpenGLTexture**
    (**QImage** (fileName).mirrored());
    texture->setMinificationFilter(**QOpenGLTexture** ::LinearMipMapLinear);
    texture->setMagnificationFilter(**QOpenGLTexture** ::Linear);
        ...
        //
    Render with texture
        texture->bind();
        glDrawArrays(...);

    Note that the **QImage**  is mirrored vertically to account for the fact
    that OpenGL and **QImage**  use opposite directions for the y axis. Another
    option would be to transform your texture coordinates.
    """

    class ComparisonMode(enum.Enum):
        CompareRefToTexture: QOpenGLTexture = ...
        CompareNone: QOpenGLTexture = ...

    class ComparisonFunction(enum.Enum):
        CompareLessEqual: QOpenGLTexture = ...
        CompareGreaterEqual: QOpenGLTexture = ...
        CompareLess: QOpenGLTexture = ...
        CompareGreater: QOpenGLTexture = ...
        CompareEqual: QOpenGLTexture = ...
        CommpareNotEqual: QOpenGLTexture = ...
        CompareAlways: QOpenGLTexture = ...
        CompareNever: QOpenGLTexture = ...
        CompareNotEqual: QOpenGLTexture = ...

    class CoordinateDirection(enum.Enum):
        DirectionS: QOpenGLTexture = ...
        DirectionT: QOpenGLTexture = ...
        DirectionR: QOpenGLTexture = ...

    class WrapMode(enum.Enum):
        Repeat: QOpenGLTexture = ...
        MirroredRepeat: QOpenGLTexture = ...
        ClampToEdge: QOpenGLTexture = ...
        ClampToBorder: QOpenGLTexture = ...

    class Filter(enum.Enum):
        Nearest: QOpenGLTexture = ...
        Linear: QOpenGLTexture = ...
        NearestMipMapNearest: QOpenGLTexture = ...
        NearestMipMapLinear: QOpenGLTexture = ...
        LinearMipMapNearest: QOpenGLTexture = ...
        LinearMipMapLinear: QOpenGLTexture = ...

    class DepthStencilMode(enum.Enum):
        DepthMode: QOpenGLTexture = ...
        StencilMode: QOpenGLTexture = ...

    class SwizzleValue(enum.Enum):
        RedValue: QOpenGLTexture = ...
        GreenValue: QOpenGLTexture = ...
        BlueValue: QOpenGLTexture = ...
        AlphaValue: QOpenGLTexture = ...
        ZeroValue: QOpenGLTexture = ...
        OneValue: QOpenGLTexture = ...

    class SwizzleComponent(enum.Enum):
        SwizzleRed: QOpenGLTexture = ...
        SwizzleGreen: QOpenGLTexture = ...
        SwizzleBlue: QOpenGLTexture = ...
        SwizzleAlpha: QOpenGLTexture = ...

    class Feature(enum.Flag):
        ImmutableStorage: QOpenGLTexture = ...
        ImmutableMultisampleStorage: QOpenGLTexture = ...
        TextureRectangle: QOpenGLTexture = ...
        TextureArrays: QOpenGLTexture = ...
        Texture3D: QOpenGLTexture = ...
        TextureMultisample: QOpenGLTexture = ...
        TextureBuffer: QOpenGLTexture = ...
        TextureCubeMapArrays: QOpenGLTexture = ...
        Swizzle: QOpenGLTexture = ...
        StencilTexturing: QOpenGLTexture = ...
        AnisotropicFiltering: QOpenGLTexture = ...
        NPOTTextures: QOpenGLTexture = ...
        NPOTTextureRepeat: QOpenGLTexture = ...
        Texture1D: QOpenGLTexture = ...
        TextureComparisonOperators: QOpenGLTexture = ...
        TextureMipMapLevel: QOpenGLTexture = ...

    class PixelType(enum.Enum):
        NoPixelType: QOpenGLTexture = ...
        Int8: QOpenGLTexture = ...
        UInt8: QOpenGLTexture = ...
        Int16: QOpenGLTexture = ...
        UInt16: QOpenGLTexture = ...
        Int32: QOpenGLTexture = ...
        UInt32: QOpenGLTexture = ...
        Float16: QOpenGLTexture = ...
        Float16OES: QOpenGLTexture = ...
        Float32: QOpenGLTexture = ...
        UInt32_RGB9_E5: QOpenGLTexture = ...
        UInt32_RG11B10F: QOpenGLTexture = ...
        UInt8_RG3B2: QOpenGLTexture = ...
        UInt8_RG3B2_Rev: QOpenGLTexture = ...
        UInt16_RGB5A1: QOpenGLTexture = ...
        UInt16_RGB5A1_Rev: QOpenGLTexture = ...
        UInt16_R5G6B5: QOpenGLTexture = ...
        UInt16_R5G6B5_Rev: QOpenGLTexture = ...
        UInt16_RGBA4: QOpenGLTexture = ...
        UInt16_RGBA4_Rev: QOpenGLTexture = ...
        UInt32_RGB10A2: QOpenGLTexture = ...
        UInt32_RGB10A2_Rev: QOpenGLTexture = ...
        UInt32_RGBA8: QOpenGLTexture = ...
        UInt32_RGBA8_Rev: QOpenGLTexture = ...
        UInt32_D24S8: QOpenGLTexture = ...
        Float32_D32_UInt32_S8_X24: QOpenGLTexture = ...

    class PixelFormat(enum.Enum):
        NoSourceFormat: QOpenGLTexture = ...
        Red: QOpenGLTexture = ...
        RG: QOpenGLTexture = ...
        RGB: QOpenGLTexture = ...
        BGR: QOpenGLTexture = ...
        RGBA: QOpenGLTexture = ...
        BGRA: QOpenGLTexture = ...
        Red_Integer: QOpenGLTexture = ...
        RG_Integer: QOpenGLTexture = ...
        RGB_Integer: QOpenGLTexture = ...
        BGR_Integer: QOpenGLTexture = ...
        RGBA_Integer: QOpenGLTexture = ...
        BGRA_Integer: QOpenGLTexture = ...
        Depth: QOpenGLTexture = ...
        DepthStencil: QOpenGLTexture = ...
        Alpha: QOpenGLTexture = ...
        Luminance: QOpenGLTexture = ...
        LuminanceAlpha: QOpenGLTexture = ...
        Stencil: QOpenGLTexture = ...

    class CubeMapFace(enum.Enum):
        CubeMapPositiveX: QOpenGLTexture = ...
        CubeMapNegativeX: QOpenGLTexture = ...
        CubeMapPositiveY: QOpenGLTexture = ...
        CubeMapNegativeY: QOpenGLTexture = ...
        CubeMapPositiveZ: QOpenGLTexture = ...
        CubeMapNegativeZ: QOpenGLTexture = ...

    class TextureFormat(enum.Enum):
        NoFormat: QOpenGLTexture = ...
        R8_UNorm: QOpenGLTexture = ...
        RG8_UNorm: QOpenGLTexture = ...
        RGB8_UNorm: QOpenGLTexture = ...
        RGBA8_UNorm: QOpenGLTexture = ...
        R16_UNorm: QOpenGLTexture = ...
        RG16_UNorm: QOpenGLTexture = ...
        RGB16_UNorm: QOpenGLTexture = ...
        RGBA16_UNorm: QOpenGLTexture = ...
        R8_SNorm: QOpenGLTexture = ...
        RG8_SNorm: QOpenGLTexture = ...
        RGB8_SNorm: QOpenGLTexture = ...
        RGBA8_SNorm: QOpenGLTexture = ...
        R16_SNorm: QOpenGLTexture = ...
        RG16_SNorm: QOpenGLTexture = ...
        RGB16_SNorm: QOpenGLTexture = ...
        RGBA16_SNorm: QOpenGLTexture = ...
        R8U: QOpenGLTexture = ...
        RG8U: QOpenGLTexture = ...
        RGB8U: QOpenGLTexture = ...
        RGBA8U: QOpenGLTexture = ...
        R16U: QOpenGLTexture = ...
        RG16U: QOpenGLTexture = ...
        RGB16U: QOpenGLTexture = ...
        RGBA16U: QOpenGLTexture = ...
        R32U: QOpenGLTexture = ...
        RG32U: QOpenGLTexture = ...
        RGB32U: QOpenGLTexture = ...
        RGBA32U: QOpenGLTexture = ...
        R8I: QOpenGLTexture = ...
        RG8I: QOpenGLTexture = ...
        RGB8I: QOpenGLTexture = ...
        RGBA8I: QOpenGLTexture = ...
        R16I: QOpenGLTexture = ...
        RG16I: QOpenGLTexture = ...
        RGB16I: QOpenGLTexture = ...
        RGBA16I: QOpenGLTexture = ...
        R32I: QOpenGLTexture = ...
        RG32I: QOpenGLTexture = ...
        RGB32I: QOpenGLTexture = ...
        RGBA32I: QOpenGLTexture = ...
        R16F: QOpenGLTexture = ...
        RG16F: QOpenGLTexture = ...
        RGB16F: QOpenGLTexture = ...
        RGBA16F: QOpenGLTexture = ...
        R32F: QOpenGLTexture = ...
        RG32F: QOpenGLTexture = ...
        RGB32F: QOpenGLTexture = ...
        RGBA32F: QOpenGLTexture = ...
        RGB9E5: QOpenGLTexture = ...
        RG11B10F: QOpenGLTexture = ...
        RG3B2: QOpenGLTexture = ...
        R5G6B5: QOpenGLTexture = ...
        RGB5A1: QOpenGLTexture = ...
        RGBA4: QOpenGLTexture = ...
        RGB10A2: QOpenGLTexture = ...
        D16: QOpenGLTexture = ...
        D24: QOpenGLTexture = ...
        D24S8: QOpenGLTexture = ...
        D32: QOpenGLTexture = ...
        D32F: QOpenGLTexture = ...
        D32FS8X24: QOpenGLTexture = ...
        RGB_DXT1: QOpenGLTexture = ...
        RGBA_DXT1: QOpenGLTexture = ...
        RGBA_DXT3: QOpenGLTexture = ...
        RGBA_DXT5: QOpenGLTexture = ...
        R_ATI1N_UNorm: QOpenGLTexture = ...
        R_ATI1N_SNorm: QOpenGLTexture = ...
        RG_ATI2N_UNorm: QOpenGLTexture = ...
        RG_ATI2N_SNorm: QOpenGLTexture = ...
        RGB_BP_UNSIGNED_FLOAT: QOpenGLTexture = ...
        RGB_BP_SIGNED_FLOAT: QOpenGLTexture = ...
        RGB_BP_UNorm: QOpenGLTexture = ...
        SRGB8: QOpenGLTexture = ...
        SRGB8_Alpha8: QOpenGLTexture = ...
        SRGB_DXT1: QOpenGLTexture = ...
        SRGB_Alpha_DXT1: QOpenGLTexture = ...
        SRGB_Alpha_DXT3: QOpenGLTexture = ...
        SRGB_Alpha_DXT5: QOpenGLTexture = ...
        SRGB_BP_UNorm: QOpenGLTexture = ...
        DepthFormat: QOpenGLTexture = ...
        AlphaFormat: QOpenGLTexture = ...
        RGBFormat: QOpenGLTexture = ...
        RGBAFormat: QOpenGLTexture = ...
        LuminanceFormat: QOpenGLTexture = ...
        LuminanceAlphaFormat: QOpenGLTexture = ...
        S8: QOpenGLTexture = ...
        R11_EAC_UNorm: QOpenGLTexture = ...
        R11_EAC_SNorm: QOpenGLTexture = ...
        RG11_EAC_UNorm: QOpenGLTexture = ...
        RG11_EAC_SNorm: QOpenGLTexture = ...
        RGB8_ETC2: QOpenGLTexture = ...
        SRGB8_ETC2: QOpenGLTexture = ...
        RGB8_PunchThrough_Alpha1_ETC2: QOpenGLTexture = ...
        SRGB8_PunchThrough_Alpha1_ETC2: QOpenGLTexture = ...
        RGBA8_ETC2_EAC: QOpenGLTexture = ...
        SRGB8_Alpha8_ETC2_EAC: QOpenGLTexture = ...
        RGB8_ETC1: QOpenGLTexture = ...
        RGBA_ASTC_4x4: QOpenGLTexture = ...
        RGBA_ASTC_5x4: QOpenGLTexture = ...
        RGBA_ASTC_5x5: QOpenGLTexture = ...
        RGBA_ASTC_6x5: QOpenGLTexture = ...
        RGBA_ASTC_6x6: QOpenGLTexture = ...
        RGBA_ASTC_8x5: QOpenGLTexture = ...
        RGBA_ASTC_8x6: QOpenGLTexture = ...
        RGBA_ASTC_8x8: QOpenGLTexture = ...
        RGBA_ASTC_10x5: QOpenGLTexture = ...
        RGBA_ASTC_10x6: QOpenGLTexture = ...
        RGBA_ASTC_10x8: QOpenGLTexture = ...
        RGBA_ASTC_10x10: QOpenGLTexture = ...
        RGBA_ASTC_12x10: QOpenGLTexture = ...
        RGBA_ASTC_12x12: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_4x4: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_5x4: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_5x5: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_6x5: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_6x6: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_8x5: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_8x6: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_8x8: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_10x5: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_10x6: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_10x8: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_10x10: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_12x10: QOpenGLTexture = ...
        SRGB8_Alpha8_ASTC_12x12: QOpenGLTexture = ...

    class TextureUnitReset(enum.Enum):
        ResetTextureUnit: QOpenGLTexture = ...
        DontResetTextureUnit: QOpenGLTexture = ...

    class MipMapGeneration(enum.Enum):
        GenerateMipMaps: QOpenGLTexture = ...
        DontGenerateMipMaps: QOpenGLTexture = ...

    class BindingTarget(enum.Enum):
        BindingTarget1D: QOpenGLTexture = ...
        BindingTarget1DArray: QOpenGLTexture = ...
        BindingTarget2D: QOpenGLTexture = ...
        BindingTarget2DArray: QOpenGLTexture = ...
        BindingTarget3D: QOpenGLTexture = ...
        BindingTargetCubeMap: QOpenGLTexture = ...
        BindingTargetCubeMapArray: QOpenGLTexture = ...
        BindingTarget2DMultisample: QOpenGLTexture = ...
        BindingTarget2DMultisampleArray: QOpenGLTexture = ...
        BindingTargetRectangle: QOpenGLTexture = ...
        BindingTargetBuffer: QOpenGLTexture = ...

    class Target(enum.Enum):
        Target1D: QOpenGLTexture = ...
        Target1DArray: QOpenGLTexture = ...
        Target2D: QOpenGLTexture = ...
        Target2DArray: QOpenGLTexture = ...
        Target3D: QOpenGLTexture = ...
        TargetCubeMap: QOpenGLTexture = ...
        TargetCubeMapArray: QOpenGLTexture = ...
        Target2DMultisample: QOpenGLTexture = ...
        Target2DMultisampleArray: QOpenGLTexture = ...
        TargetRectangle: QOpenGLTexture = ...
        TargetBuffer: QOpenGLTexture = ...

    @typing.overload
    def __init__(self, target: "QOpenGLTexture.Target") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#QOpenGLTexture

        **QOpenGLTexture::QOpenGLTexture(QOpenGLTexture::Target target )**

        Creates a QOpenGLTexture object that can later be bound to **target**.

        This does not create the underlying OpenGL texture object. Therefore,
        construction using this constructor does not require a valid current
        OpenGL context.
        """
        ...

    @typing.overload
    def __init__(
        self, image: QtGui.QImage, genMipMaps: "QOpenGLTexture.MipMapGeneration" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#QOpenGLTexture-1

        **QOpenGLTexture::QOpenGLTexture(const QImage & image ,
        QOpenGLTexture::MipMapGeneration genMipMaps = GenerateMipMaps)**

        Creates a QOpenGLTexture object that can later be bound to the 2D
        texture target and contains the pixel data contained in **image**. If
        you wish to have a chain of mipmaps generated then set **genMipMaps** to
        `true` (this is the default).

        This does create the underlying OpenGL texture object. Therefore,
        construction using this constructor does require a valid current OpenGL
        context.
        """
        ...

    def comparisonMode(self) -> "QOpenGLTexture.ComparisonMode":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#comparisonMode

        **[since 5.5] QOpenGLTexture::ComparisonMode
        QOpenGLTexture::comparisonMode() const**

        Returns the texture comparison mode set on this texture. By default, a
        texture has a **CompareNone**  comparison mode (i.e. comparisons are
        disabled).

        This function was introduced in Qt 5.5.

        **See also** **setComparisonMode** ().
        """
        ...

    def setComparisonMode(self, mode: "QOpenGLTexture.ComparisonMode") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setComparisonMode

        **[since 5.5] void
        QOpenGLTexture::setComparisonMode(QOpenGLTexture::ComparisonMode mode
        )**

        Sets the texture comparison mode on this texture to **mode**. The
        texture comparison mode is used by shadow samplers when sampling a depth
        texture.

        This function was introduced in Qt 5.5.

        **See also** **comparisonMode** ().
        """
        ...

    def comparisonFunction(self) -> "QOpenGLTexture.ComparisonFunction":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#comparisonFunction

        **[since 5.5] QOpenGLTexture::ComparisonFunction
        QOpenGLTexture::comparisonFunction() const**

        Returns the texture comparison operator set on this texture. By default,
        a texture has a **CompareLessEqual**  comparison function.

        This function was introduced in Qt 5.5.

        **See also** **setComparisonFunction** ().
        """
        ...

    def setComparisonFunction(
        self, function: "QOpenGLTexture.ComparisonFunction"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setComparisonFunction

        **[since 5.5] void
        QOpenGLTexture::setComparisonFunction(QOpenGLTexture::ComparisonFunction
        function )**

        Sets the texture comparison function on this texture to **function**.
        The texture comparison function is used by shadow samplers when sampling
        a depth texture.

        This function was introduced in Qt 5.5.

        **See also** **comparisonFunction** ().
        """
        ...

    def isFixedSamplePositions(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isFixedSamplePositions

        **bool QOpenGLTexture::isFixedSamplePositions() const**

        Returns whether this texture uses a fixed pattern of multisample
        samples. If storage has not yet been allocated for this texture then
        this function returns the requested fixed sample position setting.

        For texture targets that do not support multisampling this will return
        `true`.

        **See also** **setFixedSamplePositions** () and **isStorageAllocated**
        ().
        """
        ...

    def setFixedSamplePositions(self, fixed: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setFixedSamplePositions

        **void QOpenGLTexture::setFixedSamplePositions(bool fixed )**

        Sets whether the sample positions and number of samples used with a
        multisample capable texture target to **fixed**. If set to `true` the
        sample positions and number of samples used are the same for all texels
        in the image and will not depend upon the image size or internal format.
        This function should be called before storage is allocated for the
        texture.

        For targets that do not support multisampling this function has no
        effect.

        The default value is `true`.

        **See also** **isFixedSamplePositions** () and **isStorageAllocated**
        ().
        """
        ...

    def samples(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#samples

        **int QOpenGLTexture::samples() const**

        Returns the number of multisample sample points for this texture. If
        storage has not yet been allocated for this texture then this function
        returns the requested number of samples.

        For texture targets that do not support multisampling this will return
        0.

        **See also** **setSamples** () and **isStorageAllocated** ().
        """
        ...

    def setSamples(self, samples: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setSamples

        **void QOpenGLTexture::setSamples(int samples )**

        Sets the number of **samples** to allocate storage for when rendering to
        a multisample capable texture target. This function should be called
        before storage is allocated for the texture.

        For targets that do not support multisampling this function has no
        effect.

        **See also** **samples** () and **isStorageAllocated** ().
        """
        ...

    def target(self) -> "QOpenGLTexture.Target":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#target

        **[since 5.4] QOpenGLTexture::Target QOpenGLTexture::target() const**

        Returns the binding target of this texture.

        This function was introduced in Qt 5.4.
        """
        ...

    def levelofDetailBias(self) -> float:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#levelofDetailBias

        **float QOpenGLTexture::levelofDetailBias() const**

        Returns the level of detail bias parameter.

        **See also** **setLevelofDetailBias** ().
        """
        ...

    def setLevelofDetailBias(self, bias: float) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setLevelofDetailBias

        **void QOpenGLTexture::setLevelofDetailBias(float bias )**

        Sets the level of detail bias to **bias**. Level of detail bias affects
        the point at which mipmapping levels change. Increasing values for level
        of detail bias makes the overall images blurrier or smoother. Decreasing
        values make the overall images sharper.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **levelofDetailBias** ().
        """
        ...

    def levelOfDetailRange(self) -> typing.Tuple[float, float]:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#levelOfDetailRange

        **QPair<float, float> QOpenGLTexture::levelOfDetailRange() const**

        Returns the minimum and maximum level of detail parameters.

        **See also** **setLevelOfDetailRange** (), **minimumLevelOfDetail** (),
        and **maximumLevelOfDetail** ().
        """
        ...

    def setLevelOfDetailRange(self, min: float, max: float) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setLevelOfDetailRange

        **void QOpenGLTexture::setLevelOfDetailRange(float min , float max )**

        Sets the minimum level of detail parameters to **min** and the maximum
        level to **max**.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **levelOfDetailRange** (), **setMinimumLevelOfDetail** (),
        and **setMaximumLevelOfDetail** ().
        """
        ...

    def maximumLevelOfDetail(self) -> float:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#maximumLevelOfDetail

        **float QOpenGLTexture::maximumLevelOfDetail() const**

        Returns the maximum level of detail parameter.

        **See also** **setMaximumLevelOfDetail** (), **minimumLevelOfDetail**
        (), and **levelOfDetailRange** ().
        """
        ...

    def setMaximumLevelOfDetail(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMaximumLevelOfDetail

        **void QOpenGLTexture::setMaximumLevelOfDetail(float value )**

        Sets the maximum level of detail to **value**. This limits the selection
        of lowest resolution mipmap (highest mipmap level). The default value is
        1000.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **maximumLevelOfDetail** (), **setMinimumLevelOfDetail**
        (), and **setLevelOfDetailRange** ().
        """
        ...

    def minimumLevelOfDetail(self) -> float:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#minimumLevelOfDetail

        **float QOpenGLTexture::minimumLevelOfDetail() const**

        Returns the minimum level of detail parameter.

        **See also** **setMinimumLevelOfDetail** (), **maximumLevelOfDetail**
        (), and **levelOfDetailRange** ().
        """
        ...

    def setMinimumLevelOfDetail(self, value: float) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMinimumLevelOfDetail

        **void QOpenGLTexture::setMinimumLevelOfDetail(float value )**

        Sets the minimum level of detail to **value**. This limits the selection
        of highest resolution mipmap (lowest mipmap level). The default value is
        -1000.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **minimumLevelOfDetail** (), **setMaximumLevelOfDetail**
        (), and **setLevelOfDetailRange** ().
        """
        ...

    def borderColor(self) -> QtGui.QColor:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#borderColor

        **QColor QOpenGLTexture::borderColor() const**

        Returns the borderColor of this texture.

        **See also** **setBorderColor** ().
        """
        ...

    def setBorderColor(
        self, color: typing.Union[QtGui.QColor, QtCore.Qt.GlobalColor, int]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setBorderColor

        **void QOpenGLTexture::setBorderColor(const QColor & color )**

        Sets the border color of the texture to **color**.

        **Note:** This function has no effect on Mac and Qt built for OpenGL ES
        2.

        **See also** **borderColor** ().
        """
        ...

    def wrapMode(
        self, direction: "QOpenGLTexture.CoordinateDirection"
    ) -> "QOpenGLTexture.WrapMode":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#wrapMode

        **QOpenGLTexture::WrapMode
        QOpenGLTexture::wrapMode(QOpenGLTexture::CoordinateDirection direction )
        const**

        Returns the wrap mode for the texture dimension **direction**.

        **See also** **setWrapMode** ().
        """
        ...

    @typing.overload
    def setWrapMode(self, mode: "QOpenGLTexture.WrapMode") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setWrapMode

        **void QOpenGLTexture::setWrapMode(QOpenGLTexture::WrapMode mode )**

        Sets the wrap (or repeat mode) for all texture dimentions to **mode**.

        **See also** **wrapMode** ().
        """
        ...

    @typing.overload
    def setWrapMode(
        self,
        direction: "QOpenGLTexture.CoordinateDirection",
        mode: "QOpenGLTexture.WrapMode",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setWrapMode-1

        **void QOpenGLTexture::setWrapMode(QOpenGLTexture::CoordinateDirection
        direction , QOpenGLTexture::WrapMode mode )**

        Holds the texture dimension **direction**.

        This is an overloaded function.
        """
        ...

    def maximumAnisotropy(self) -> float:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#maximumAnisotropy

        **float QOpenGLTexture::maximumAnisotropy() const**

        Returns the maximum level of anisotropy to be accounted for when
        performing texture lookups. This requires the
        GL_EXT_texture_filter_anisotropic extension.

        **See also** **setMaximumAnisotropy** ().
        """
        ...

    def setMaximumAnisotropy(self, anisotropy: float) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMaximumAnisotropy

        **void QOpenGLTexture::setMaximumAnisotropy(float anisotropy )**

        If your OpenGL implementation supports the
        GL_EXT_texture_filter_anisotropic extension this function sets the
        maximum anisotropy level to **anisotropy**.

        **See also** **maximumAnisotropy** ().
        """
        ...

    def minMagFilters(
        self,
    ) -> typing.Tuple["QOpenGLTexture.Filter", "QOpenGLTexture.Filter"]:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#minMagFilters

        **QPair<QOpenGLTexture::Filter, QOpenGLTexture::Filter>
        QOpenGLTexture::minMagFilters() const**

        Returns the current minification and magnification filters.

        **See also** **setMinMagFilters** ().
        """
        ...

    def setMinMagFilters(
        self,
        minificationFilter: "QOpenGLTexture.Filter",
        magnificationFilter: "QOpenGLTexture.Filter",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMinMagFilters

        **void QOpenGLTexture::setMinMagFilters(QOpenGLTexture::Filter
        minificationFilter , QOpenGLTexture::Filter magnificationFilter )**

        Sets the minification filter to **minificationFilter** and the
        magnification filter to **magnificationFilter**.

        **See also** **minMagFilters** (), **setMinificationFilter** (), and
        **setMagnificationFilter** ().
        """
        ...

    def magnificationFilter(self) -> "QOpenGLTexture.Filter":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#magnificationFilter

        **QOpenGLTexture::Filter QOpenGLTexture::magnificationFilter() const**

        Returns the magnification filter.

        **See also** **setMagnificationFilter** ().
        """
        ...

    def setMagnificationFilter(self, filter: "QOpenGLTexture.Filter") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMagnificationFilter

        **void QOpenGLTexture::setMagnificationFilter(QOpenGLTexture::Filter
        filter )**

        Sets the magnification filter to **filter**.

        **See also** **magnificationFilter** (), **setMinificationFilter** (),
        and **setMinMagFilters** ().
        """
        ...

    def minificationFilter(self) -> "QOpenGLTexture.Filter":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#minificationFilter

        **QOpenGLTexture::Filter QOpenGLTexture::minificationFilter() const**

        Returns the minification filter.

        **See also** **setMinificationFilter** ().
        """
        ...

    def setMinificationFilter(self, filter: "QOpenGLTexture.Filter") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMinificationFilter

        **void QOpenGLTexture::setMinificationFilter(QOpenGLTexture::Filter
        filter )**

        Sets the filter used for minification to **filter**.

        **See also** **minificationFilter** (), **setMagnificationFilter** (),
        and **setMinMagFilters** ().
        """
        ...

    def depthStencilMode(self) -> "QOpenGLTexture.DepthStencilMode":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#depthStencilMode

        **[since 5.4] QOpenGLTexture::DepthStencilMode
        QOpenGLTexture::depthStencilMode() const**

        Returns the depth stencil mode for textures using a combined
        depth/stencil format.

        This function was introduced in Qt 5.4.

        **See also** **setDepthStencilMode** ().
        """
        ...

    def setDepthStencilMode(self, mode: "QOpenGLTexture.DepthStencilMode") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setDepthStencilMode

        **[since 5.4] void
        QOpenGLTexture::setDepthStencilMode(QOpenGLTexture::DepthStencilMode
        mode )**

        If using a texture that has a combined depth/stencil format this
        function sets which component of the texture is accessed to **mode**.

        When the parameter is set to **DepthMode** , then accessing it from the
        shader will access the depth component as a single float, as normal. But
        when the parameter is set to **StencilMode** , the shader will access
        the stencil component.

        **Note:** This function has no effect on Mac and Qt built for OpenGL ES
        2.

        This function was introduced in Qt 5.4.

        **See also** **depthStencilMode** ().
        """
        ...

    def swizzleMask(
        self, component: "QOpenGLTexture.SwizzleComponent"
    ) -> "QOpenGLTexture.SwizzleValue":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#swizzleMask

        **QOpenGLTexture::SwizzleValue
        QOpenGLTexture::swizzleMask(QOpenGLTexture::SwizzleComponent component )
        const**

        Returns the swizzle mask for texture **component**.

        **See also** **setSwizzleMask** ().
        """
        ...

    @typing.overload
    def setSwizzleMask(
        self,
        component: "QOpenGLTexture.SwizzleComponent",
        value: "QOpenGLTexture.SwizzleValue",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setSwizzleMask

        **void QOpenGLTexture::setSwizzleMask(QOpenGLTexture::SwizzleComponent
        component , QOpenGLTexture::SwizzleValue value )**

        GLSL shaders are able to reorder the components of the vec4 returned by
        texture functions. It is also desirable to be able to control this
        reordering from CPU side code. This is made possible by swizzle masks
        since OpenGL 3.3.

        Each component of the texture can be mapped to one of the
        **SwizzleValue**  options.

        This function maps **component** to the output **value**.

        **Note:** This function has no effect on Mac and Qt built for OpenGL ES
        2.

        **See also** **swizzleMask** ().
        """
        ...

    @typing.overload
    def setSwizzleMask(
        self,
        r: "QOpenGLTexture.SwizzleValue",
        g: "QOpenGLTexture.SwizzleValue",
        b: "QOpenGLTexture.SwizzleValue",
        a: "QOpenGLTexture.SwizzleValue",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setSwizzleMask-1

        **void QOpenGLTexture::setSwizzleMask(QOpenGLTexture::SwizzleValue r ,
        QOpenGLTexture::SwizzleValue g , QOpenGLTexture::SwizzleValue b ,
        QOpenGLTexture::SwizzleValue a )**

        Parameters **r** , **g** , **b** , and **a** are values used for setting
        the colors red, green, blue, and the alpha value.

        This is an overloaded function.
        """
        ...

    @typing.overload
    def generateMipMaps(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#generateMipMaps

        **void QOpenGLTexture::generateMipMaps()**

        Generates mipmaps for this texture object from mipmap level 0. If you
        are using a texture target and filtering option that requires mipmaps
        and you have disabled automatic mipmap generation then you need to call
        this function or the overload to create the mipmap chain.

        **Note:** Mipmap generation is not supported for compressed textures
        with OpenGL ES.

        **See also** **setAutoMipMapGenerationEnabled** (), **setMipLevels** (),
        and **mipLevels** ().
        """
        ...

    @typing.overload
    def generateMipMaps(self, baseLevel: int, resetBaseLevel: bool = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#generateMipMaps-1

        **void QOpenGLTexture::generateMipMaps(int baseLevel , bool
        resetBaseLevel = true)**

        Generates mipmaps for this texture object from mipmap level
        **baseLevel**. If you are using a texture target and filtering option
        that requires mipmaps and you have disabled automatic mipmap generation
        then you need to call this function or the overload to create the mipmap
        chain.

        The generation of mipmaps to above **baseLevel** is achieved by setting
        the mipmap base level to **baseLevel** and then generating the mipmap
        chain. If **resetBaseLevel** is `true`, then the baseLevel of the
        texture will be reset to its previous value.

        **See also** **setAutoMipMapGenerationEnabled** (), **setMipLevels** (),
        and **mipLevels** ().
        """
        ...

    def isAutoMipMapGenerationEnabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isAutoMipMapGenerationEnabled

        **bool QOpenGLTexture::isAutoMipMapGenerationEnabled() const**

        Returns whether auto mipmap generation is enabled for this texture
        object.

        **See also** **setAutoMipMapGenerationEnabled** () and
        **generateMipMaps** ().
        """
        ...

    def setAutoMipMapGenerationEnabled(self, enabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setAutoMipMapGenerationEnable
        d

        **void QOpenGLTexture::setAutoMipMapGenerationEnabled(bool enabled )**

        If **enabled** is `true`, enables automatic mipmap generation for this
        texture object to occur whenever the level 0 mipmap data is set via
        **setData** ().

        The automatic mipmap generation is enabled by default.

        **Note:** Mipmap generation is not supported for compressed textures
        with OpenGL ES 2.0.

        **See also** **isAutoMipMapGenerationEnabled** () and
        **generateMipMaps** ().
        """
        ...

    def mipLevelRange(self) -> typing.Tuple[int, int]:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#mipLevelRange

        **QPair<int, int> QOpenGLTexture::mipLevelRange() const**

        Returns the range of mipmap levels that can be used for texture lookups
        with this texture.

        **See also** **setMipLevelRange** (), **mipBaseLevel** (), and
        **mipMaxLevel** ().
        """
        ...

    def setMipLevelRange(self, baseLevel: int, maxLevel: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMipLevelRange

        **void QOpenGLTexture::setMipLevelRange(int baseLevel , int maxLevel )**

        Sets the range of mipmap levels that can be used for texture lookups
        with this texture to range from **baseLevel** to **maxLevel**.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **setMipBaseLevel** (), **setMipMaxLevel** (), and
        **mipLevelRange** ().
        """
        ...

    def mipMaxLevel(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#mipMaxLevel

        **int QOpenGLTexture::mipMaxLevel() const**

        Returns the mipmap maximum level used for all texture lookups with this
        texture.

        **See also** **setMipMaxLevel** (), **mipBaseLevel** (), and
        **mipLevelRange** ().
        """
        ...

    def setMipMaxLevel(self, maxLevel: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMipMaxLevel

        **void QOpenGLTexture::setMipMaxLevel(int maxLevel )**

        Sets the maximum mipmap level used for all texture lookups with this
        texture to **maxLevel**.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **mipMaxLevel** (), **setMipBaseLevel** (), and
        **setMipLevelRange** ().
        """
        ...

    def mipBaseLevel(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#mipBaseLevel

        **int QOpenGLTexture::mipBaseLevel() const**

        Returns the mipmap base level used for all texture lookups with this
        texture. The default is 0.

        **See also** **setMipBaseLevel** (), **mipMaxLevel** (), and
        **mipLevelRange** ().
        """
        ...

    def setMipBaseLevel(self, baseLevel: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMipBaseLevel

        **void QOpenGLTexture::setMipBaseLevel(int baseLevel )**

        Sets the base mipmap level used for all texture lookups with this
        texture to **baseLevel**.

        **Note:** This function has no effect on Qt built for OpenGL ES 2.

        **See also** **mipBaseLevel** (), **setMipMaxLevel** (), and
        **setMipLevelRange** ().
        """
        ...

    @staticmethod
    def hasFeature(feature: "QOpenGLTexture.Feature") -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#hasFeature

        **[static] bool QOpenGLTexture::hasFeature(QOpenGLTexture::Feature
        feature )**

        Returns `true` if your OpenGL implementation and version supports the
        texture feature **feature**.
        """
        ...

    @typing.overload
    def setCompressedData(
        self,
        mipLevel: int,
        layer: int,
        cubeFace: "QOpenGLTexture.CubeMapFace",
        dataSize: int,
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setCompressedData

        **[since 5.3] void QOpenGLTexture::setCompressedData(int mipLevel , int
        layer , QOpenGLTexture::CubeMapFace cubeFace , int dataSize , const void
        * data , const QOpenGLPixelTransferOptions *const options = nullptr)**

        Uploads compressed pixel **data** to **mipLevel** , array **layer** ,
        and **cubeFace**. The pixel transfer can optionally be controlled with
        **options**. The **dataSize** argument should specify the size of the
        data pointed to by **data**.

        If not using a compressed **format** () then you should use **setData**
        () instead of this function.

        This function was introduced in Qt 5.3.
        """
        ...

    @typing.overload
    def setCompressedData(
        self,
        mipLevel: int,
        layer: int,
        dataSize: int,
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setCompressedData-1

        **[since 5.9] void QOpenGLTexture::setCompressedData(int mipLevel , int
        layer , int layerCount , QOpenGLTexture::CubeMapFace cubeFace , int
        dataSize , const void * data , const QOpenGLPixelTransferOptions *const
        options = nullptr)**

        This is an overloaded function.

        Parameter **layerCount** is the number of layers in a texture array that
        are being uploaded/populated by this call.

        This function was introduced in Qt 5.9.
        """
        ...

    @typing.overload
    def setCompressedData(
        self,
        mipLevel: int,
        dataSize: int,
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setCompressedData-2

        **void QOpenGLTexture::setCompressedData(int mipLevel , int layer , int
        dataSize , const void * data , const QOpenGLPixelTransferOptions *const
        options = nullptr)**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def setCompressedData(
        self,
        dataSize: int,
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setCompressedData-3

        **void QOpenGLTexture::setCompressedData(int mipLevel , int dataSize ,
        const void * data , const QOpenGLPixelTransferOptions *const options =
        nullptr)**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def setCompressedData(
        self,
        mipLevel: int,
        layer: int,
        layerCount: int,
        cubeFace: "QOpenGLTexture.CubeMapFace",
        dataSize: int,
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setCompressedData-4

        **void QOpenGLTexture::setCompressedData(int dataSize , const void *
        data , const QOpenGLPixelTransferOptions *const options = nullptr)**

        This is an overloaded function.
        """
        ...

    @typing.overload
    def setData(
        self,
        mipLevel: int,
        layer: int,
        cubeFace: "QOpenGLTexture.CubeMapFace",
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData

        **[since 5.3] void QOpenGLTexture::setData(int mipLevel , int layer ,
        QOpenGLTexture::CubeMapFace cubeFace , QOpenGLTexture::PixelFormat
        sourceFormat , QOpenGLTexture::PixelType sourceType , const void * data
        , const QOpenGLPixelTransferOptions *const options = nullptr)**

        Uploads pixel **data** for this texture object **mipLevel** , array
        **layer** , and **cubeFace**. Storage must have been allocated before
        uploading pixel data. Some overloads of setData() will set appropriate
        dimensions, mipmap levels, and array layers and then allocate storage
        for you if they have enough information to do so. This will be noted in
        the function documentation.

        The structure of the pixel data pointed to by **data** is specified by
        **sourceFormat** and **sourceType**. The pixel data upload can
        optionally be controlled by **options**.

        If using a compressed **format** () then you should use
        **setCompressedData** () instead of this function.

        This function was introduced in Qt 5.3.

        **See also** **setCompressedData** ().
        """
        ...

    @typing.overload
    def setData(
        self,
        mipLevel: int,
        layer: int,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-1

        **[since 5.9] void QOpenGLTexture::setData(int mipLevel , int layer ,
        int layerCount , QOpenGLTexture::CubeMapFace cubeFace ,
        QOpenGLTexture::PixelFormat sourceFormat , QOpenGLTexture::PixelType
        sourceType , const void * data , const QOpenGLPixelTransferOptions
        *const options = nullptr)**

        This is an overloaded function.

        Parameter **layerCount** is the number of layers in a texture array that
        are being uploaded/populated by this call.

        This function was introduced in Qt 5.9.
        """
        ...

    @typing.overload
    def setData(
        self,
        mipLevel: int,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-2

        **[since 5.3] void QOpenGLTexture::setData(int mipLevel , int layer ,
        QOpenGLTexture::PixelFormat sourceFormat , QOpenGLTexture::PixelType
        sourceType , const void * data , const QOpenGLPixelTransferOptions
        *const options = nullptr)**

        This is an overloaded function.

        This function was introduced in Qt 5.3.
        """
        ...

    @typing.overload
    def setData(
        self,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-3

        **[since 5.3] void QOpenGLTexture::setData(int mipLevel ,
        QOpenGLTexture::PixelFormat sourceFormat , QOpenGLTexture::PixelType
        sourceType , const void * data , const QOpenGLPixelTransferOptions
        *const options = nullptr)**

        This is an overloaded function.

        This function was introduced in Qt 5.3.
        """
        ...

    @typing.overload
    def setData(
        self, image: QtGui.QImage, genMipMaps: "QOpenGLTexture.MipMapGeneration" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-4

        **[since 5.3] void QOpenGLTexture::setData(QOpenGLTexture::PixelFormat
        sourceFormat , QOpenGLTexture::PixelType sourceType , const void * data
        , const QOpenGLPixelTransferOptions *const options = nullptr)**

        This is an overloaded function.

        This function was introduced in Qt 5.3.
        """
        ...

    @typing.overload
    def setData(
        self,
        mipLevel: int,
        layer: int,
        layerCount: int,
        cubeFace: "QOpenGLTexture.CubeMapFace",
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-5

        **[since 5.14] void QOpenGLTexture::setData(int xOffset , int yOffset ,
        int zOffset , int width , int height , int depth ,
        QOpenGLTexture::PixelFormat sourceFormat , QOpenGLTexture::PixelType
        sourceType , const void * data , const QOpenGLPixelTransferOptions
        *const options = nullptr)**

        This is an overloaded function.

        This overload is to be used to update a part of the texture. Parameters
        **xOffset** , **yOffset** , **zOffset** specify the texel offsets within
        the texture. Parameters **width** , **height** and **depth** specify the
        dimensions of the sub image.

        The structure of the pixel data pointed to by **data** is specified by
        **sourceFormat** and **sourceType**. The pixel data upload can
        optionally be controlled by **options**.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    def setData(
        self,
        xOffset: int,
        yOffset: int,
        zOffset: int,
        width: int,
        height: int,
        depth: int,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-6

        **[since 5.14] void QOpenGLTexture::setData(int xOffset , int yOffset ,
        int zOffset , int width , int height , int depth , int mipLevel ,
        QOpenGLTexture::PixelFormat sourceFormat , QOpenGLTexture::PixelType
        sourceType , const void * data , const QOpenGLPixelTransferOptions
        *const options = nullptr)**

        This is an overloaded function.

        This overload is to be used to update a part of the texture. Parameters
        **xOffset** , **yOffset** , **zOffset** specify the texel offsets within
        the texture. Parameters **width** , **height** and **depth** specify the
        dimensions of the sub image. The mip map level the sub image we want to
        update is specified with **mipLevel**.

        The structure of the pixel data pointed to by **data** is specified by
        **sourceFormat** and **sourceType**. The pixel data upload can
        optionally be controlled by **options**.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    def setData(
        self,
        xOffset: int,
        yOffset: int,
        zOffset: int,
        width: int,
        height: int,
        depth: int,
        mipLevel: int,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-7

        **[since 5.14] void QOpenGLTexture::setData(int xOffset , int yOffset ,
        int zOffset , int width , int height , int depth , int mipLevel , int
        layer , QOpenGLTexture::PixelFormat sourceFormat ,
        QOpenGLTexture::PixelType sourceType , const void * data , const
        QOpenGLPixelTransferOptions *const options = nullptr)**

        This is an overloaded function.

        This overload is to be used to update a part of the texture. Parameters
        **xOffset** , **yOffset** , **zOffset** specify the texel offsets within
        the texture. Parameters **width** , **height** and **depth** specify the
        dimensions of the sub image. The mip map level and layerof the sub image
        we want to update are specified with **mipLevel** and **layer**.

        The structure of the pixel data pointed to by **data** is specified by
        **sourceFormat** and **sourceType**. The pixel data upload can
        optionally be controlled by **options**.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    def setData(
        self,
        xOffset: int,
        yOffset: int,
        zOffset: int,
        width: int,
        height: int,
        depth: int,
        mipLevel: int,
        layer: int,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-8

        **[since 5.14] void QOpenGLTexture::setData(int xOffset , int yOffset ,
        int zOffset , int width , int height , int depth , int mipLevel , int
        layer , QOpenGLTexture::CubeMapFace face , QOpenGLTexture::PixelFormat
        sourceFormat , QOpenGLTexture::PixelType sourceType , const void * data
        , const QOpenGLPixelTransferOptions *const options = nullptr)**

        This is an overloaded function.

        This overload is to be used to update a part of the texture. Parameters
        **xOffset** , **yOffset** , **zOffset** specify the texel offsets within
        the texture. Parameters **width** , **height** and **depth** specify the
        dimensions of the sub image.The mip map level, layer and cube map face
        of the sub image we want to update are specified with **mipLevel** ,
        **layer** and **face**.

        The structure of the pixel data pointed to by **data** is specified by
        **sourceFormat** and **sourceType**. The pixel data upload can
        optionally be controlled by **options**.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    def setData(
        self,
        xOffset: int,
        yOffset: int,
        zOffset: int,
        width: int,
        height: int,
        depth: int,
        mipLevel: int,
        layer: int,
        cubeFace: "QOpenGLTexture.CubeMapFace",
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-9

        **[since 5.14] void QOpenGLTexture::setData(int xOffset , int yOffset ,
        int zOffset , int width , int height , int depth , int mipLevel , int
        layer , QOpenGLTexture::CubeMapFace face , int layerCount ,
        QOpenGLTexture::PixelFormat sourceFormat , QOpenGLTexture::PixelType
        sourceType , const void * data , const QOpenGLPixelTransferOptions
        *const options = nullptr)**

        This is an overloaded function.

        This overload is to be used to update a part of the texture. Parameters
        **xOffset** , **yOffset** , **zOffset** specify the texel offsets within
        the texture. Parameters **width** , **height** and **depth** specify the
        dimensions of the sub image.The mip map level, starting layer, cube map
        face and number of layers of the sub image we want to update are
        specified with **mipLevel** , **layer** , **face** and **layerCount**.

        The structure of the pixel data pointed to by **data** is specified by
        **sourceFormat** and **sourceType**. The pixel data upload can
        optionally be controlled by **options**.

        This function was introduced in Qt 5.14.
        """
        ...

    @typing.overload
    def setData(
        self,
        xOffset: int,
        yOffset: int,
        zOffset: int,
        width: int,
        height: int,
        depth: int,
        mipLevel: int,
        layer: int,
        cubeFace: "QOpenGLTexture.CubeMapFace",
        layerCount: int,
        sourceFormat: "QOpenGLTexture.PixelFormat",
        sourceType: "QOpenGLTexture.PixelType",
        data: PyQt6.sip.voidptr,
        options: typing.Optional[QOpenGLPixelTransferOptions] = ...,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setData-10

        **void QOpenGLTexture::setData(const QImage & image ,
        QOpenGLTexture::MipMapGeneration genMipMaps = GenerateMipMaps)**

        This overload of setData() will allocate storage for you. The pixel data
        is contained in **image**. Mipmaps are generated by default. Set
        **genMipMaps** to **DontGenerateMipMaps**  to turn off mipmap
        generation.

        This is an overloaded function.
        """
        ...

    def isTextureView(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isTextureView

        **bool QOpenGLTexture::isTextureView() const**

        Returns `true` if this texture object is actually a view onto another
        texture object.

        **See also** **createTextureView** ().
        """
        ...

    def createTextureView(
        self,
        target: "QOpenGLTexture.Target",
        viewFormat: "QOpenGLTexture.TextureFormat",
        minimumMipmapLevel: int,
        maximumMipmapLevel: int,
        minimumLayer: int,
        maximumLayer: int,
    ) -> "QOpenGLTexture":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#createTextureView

        **QOpenGLTexture
        *QOpenGLTexture::createTextureView(QOpenGLTexture::Target target ,
        QOpenGLTexture::TextureFormat viewFormat , int minimumMipmapLevel , int
        maximumMipmapLevel , int minimumLayer , int maximumLayer ) const**

        Attempts to create a texture view onto this texture. A texture view is
        somewhat analogous to a view in SQL in that it presents a restricted or
        reinterpreted view of the original data. Texture views do not allocate
        any more server-side storage, insted relying on the storage buffer of
        the source texture.

        Texture views are only available when using immutable storage. For more
        information on texture views see
        http://www.opengl.org/wiki/Texture_Storage#Texture_views.

        The **target** argument specifies the target to use for the view. Only
        some targets can be used depending upon the target of the original
        target. For e.g. a view onto a **Target1DArray**  texture can specify
        either **Target1DArray**  or **Target1D**  but for the latter the number
        of array layers specified with **minimumLayer** and **maximumLayer**
        must be exactly 1.

        Simpliar constraints apply for the **viewFormat**. See the above link
        and the specification for more details.

        The **minimumMipmapLevel** , **maximumMipmapLevel** , **minimumLayer** ,
        and **maximumLayer** arguments serve to restrict the parts of the
        texture accessible by the texture view.

        If creation of the texture view fails this function will return 0. If
        the function succeeds it will return a pointer to a new
        **QOpenGLTexture**  object that will return `true` from its
        **isTextureView** () function.

        **See also** **isTextureView** ().
        """
        ...

    def isStorageAllocated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isStorageAllocated

        **bool QOpenGLTexture::isStorageAllocated() const**

        Returns `true` if server-side storage for this texture as been
        allocated.

        The texture format, dimensions, mipmap levels and array layers cannot be
        altered once storage ihas been allocated.

        **See also** **allocateStorage** (), **setSize** (), **setMipLevels**
        (), **setLayers** (), and **setFormat** ().
        """
        ...

    @typing.overload
    def allocateStorage(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#allocateStorage

        **void QOpenGLTexture::allocateStorage()**

        Allocates server-side storage for this texture object taking into
        account, the format, dimensions, mipmap levels, array layers and cubemap
        faces.

        Once storage has been allocated it is no longer possible to change these
        properties.

        If supported **QOpenGLTexture**  makes use of immutable texture storage.

        Once storage has been allocated for the texture then pixel data can be
        uploaded via one of the **setData** () overloads.

        **Note:** If immutable texture storage is not available, then a default
        pixel format and pixel type will be used to create the mutable storage.
        You can use the other allocateStorage() overload to specify exactly the
        pixel format and the pixel type to use when allocating mutable storage;
        this is particulary useful under certain OpenGL ES implementations
        (notably, OpenGL ES 2), where the pixel format and the pixel type used
        at allocation time must perfectly match the format and the type passed
        to any subsequent **setData** () call.

        **See also** **isStorageAllocated** () and **setData** ().
        """
        ...

    @typing.overload
    def allocateStorage(
        self,
        pixelFormat: "QOpenGLTexture.PixelFormat",
        pixelType: "QOpenGLTexture.PixelType",
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#allocateStorage-1

        **[since 5.5] void
        QOpenGLTexture::allocateStorage(QOpenGLTexture::PixelFormat pixelFormat
        , QOpenGLTexture::PixelType pixelType )**

        Allocates server-side storage for this texture object taking into
        account, the format, dimensions, mipmap levels, array layers and cubemap
        faces.

        Once storage has been allocated it is no longer possible to change these
        properties.

        If supported **QOpenGLTexture**  makes use of immutable texture storage.
        However, if immutable texture storage is not available, then the
        specified **pixelFormat** and **pixelType** will be used to allocate
        mutable storage; note that in certain OpenGL implementations (notably,
        OpenGL ES 2) they must perfectly match the format and the type passed to
        any subsequent **setData** () call.

        Once storage has been allocated for the texture then pixel data can be
        uploaded via one of the **setData** () overloads.

        This function was introduced in Qt 5.5.

        **See also** **isStorageAllocated** () and **setData** ().
        """
        ...

    def faces(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#faces

        **int QOpenGLTexture::faces() const**

        Returns the number of faces for this texture. For cubemap and cubemap
        array type targets this will be 6.

        For non-cubemap type targets this will return 1.
        """
        ...

    def layers(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#layers

        **int QOpenGLTexture::layers() const**

        Returns the number of array layers for this texture. If storage has not
        yet been allocated for this texture then this function returns the
        requested number of array layers.

        For texture targets that do not support array layers this will return 1.

        **See also** **setLayers** () and **isStorageAllocated** ().
        """
        ...

    def setLayers(self, layers: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setLayers

        **void QOpenGLTexture::setLayers(int layers )**

        Sets the number of array **layers** to allocate storage for. This
        function should be called before storage is allocated for the texture.

        For targets that do not support array layers this function has no
        effect.

        **See also** **layers** () and **isStorageAllocated** ().
        """
        ...

    def maximumMipLevels(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#maximumMipLevels

        **int QOpenGLTexture::maximumMipLevels() const**

        Returns the maximum number of mipmap levels that this texture can have
        given the current dimensions.

        **See also** **setMipLevels** (), **mipLevels** (), and **setSize** ().
        """
        ...

    def mipLevels(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#mipLevels

        **int QOpenGLTexture::mipLevels() const**

        Returns the number of mipmap levels for this texture. If storage has not
        yet been allocated for this texture it returns the requested number of
        mipmap levels.

        **See also** **setMipLevels** (), **maximumMipLevels** (), and
        **isStorageAllocated** ().
        """
        ...

    def setMipLevels(self, levels: int) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setMipLevels

        **void QOpenGLTexture::setMipLevels(int levels )**

        For texture targets that support mipmaps, this function sets the
        requested number of mipmap **levels** to allocate storage for. This
        function should be called before storage is allocated for the texture.

        If the texture target does not support mipmaps this function has no
        effect.

        **See also** **mipLevels** (), **maximumMipLevels** (), and
        **isStorageAllocated** ().
        """
        ...

    def depth(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#depth

        **int QOpenGLTexture::depth() const**

        Returns the depth of a 3D texture.

        **See also** **width** (), **height** (), and **setSize** ().
        """
        ...

    def height(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#height

        **int QOpenGLTexture::height() const**

        Returns the height of a 2D or 3D texture.

        **See also** **width** (), **depth** (), and **setSize** ().
        """
        ...

    def width(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#width

        **int QOpenGLTexture::width() const**

        Returns the width of a 1D, 2D or 3D texture.

        **See also** **height** (), **depth** (), and **setSize** ().
        """
        ...

    def setSize(self, width: int, height: int = ..., depth: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setSize

        **void QOpenGLTexture::setSize(int width , int height = 1, int depth =
        1)**

        Sets the dimensions of this texture object to **width** , **height** ,
        and **depth**. The default for each dimension is 1. The maximum
        allowable texture size is dependent upon your OpenGL implementation.
        Allocating storage for a texture less than the maximum size can still
        fail if your system is low on resources.

        If a non-power-of-two **width** , **height** or **depth** is provided
        and your OpenGL implementation doesn't have support for repeating non-
        power-of-two textures, then the wrap mode is automatically set to
        **ClampToEdge** .

        **See also** **width** (), **height** (), and **depth** ().
        """
        ...

    def format(self) -> "QOpenGLTexture.TextureFormat":
        """
        https://doc.qt.io/qt-6/qopengltexture.html#format

        **QOpenGLTexture::TextureFormat QOpenGLTexture::format() const**

        Returns the format of this texture object.

        **See also** **setFormat** ().
        """
        ...

    def setFormat(self, format: "QOpenGLTexture.TextureFormat") -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#setFormat

        **void QOpenGLTexture::setFormat(QOpenGLTexture::TextureFormat format
        )**

        Sets the format of this texture object to **format**. This function must
        be called before texture storage is allocated.

        Note that all formats may not be supported. The exact set of supported
        formats is dependent upon your OpenGL implementation and version.

        **See also** **format** () and **allocateStorage** ().
        """
        ...

    @typing.overload
    @staticmethod
    def boundTextureId(target: "QOpenGLTexture.BindingTarget") -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#boundTextureId

        **[static] GLuint
        QOpenGLTexture::boundTextureId(QOpenGLTexture::BindingTarget target )**

        Returns the **textureId**  of the texture that is bound to the
        **target** of the currently active texture unit.
        """
        ...

    @typing.overload
    @staticmethod
    def boundTextureId(unit: int, target: "QOpenGLTexture.BindingTarget") -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#boundTextureId-1

        **[static] GLuint QOpenGLTexture::boundTextureId(uint unit ,
        QOpenGLTexture::BindingTarget target )**

        Returns the **textureId**  of the texture that is bound to the
        **target** of the texture unit **unit**.
        """
        ...

    @typing.overload
    def isBound(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isBound

        **bool QOpenGLTexture::isBound() const**

        Returns `true` if this texture is bound to the corresponding target of
        the currently active texture unit.

        **See also** **bind** () and **release** ().
        """
        ...

    @typing.overload
    def isBound(self, unit: int) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isBound-1

        **bool QOpenGLTexture::isBound(uint unit )**

        Returns `true` if this texture is bound to the corresponding target of
        texture unit **unit**.

        **See also** **bind** () and **release** ().
        """
        ...

    @typing.overload
    def release(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#release

        **void QOpenGLTexture::release()**

        Unbinds this texture from the currently active texture unit.

        **See also** **bind** ().
        """
        ...

    @typing.overload
    def release(
        self, unit: int, reset: "QOpenGLTexture.TextureUnitReset" = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#release-1

        **void QOpenGLTexture::release(uint unit ,
        QOpenGLTexture::TextureUnitReset reset = DontResetTextureUnit)**

        Unbinds this texture from texture unit **unit**.

        If parameter **reset** is `true` then this function will restore the
        active unit to the texture unit that was active upon entry.
        """
        ...

    @typing.overload
    def bind(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#bind

        **void QOpenGLTexture::bind()**

        Binds this texture to the currently active texture unit ready for
        rendering. Note that you do not need to bind **QOpenGLTexture**  objects
        in order to modify them as the implementation makes use of the
        EXT_direct_state_access extension where available and simulates it where
        it is not.

        **See also** **release** ().
        """
        ...

    @typing.overload
    def bind(self, unit: int, reset: "QOpenGLTexture.TextureUnitReset" = ...) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#bind-1

        **void QOpenGLTexture::bind(uint unit , QOpenGLTexture::TextureUnitReset
        reset = DontResetTextureUnit)**

        Binds this texture to texture unit **unit** ready for rendering. Note
        that you do not need to bind **QOpenGLTexture**  objects in order to
        modify them as the implementation makes use of the
        EXT_direct_state_access extension where available and simulates it where
        it is not.

        If parameter **reset** is `true` then this function will restore the
        active unit to the texture unit that was active upon entry.

        **See also** **release** ().
        """
        ...

    def textureId(self) -> int:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#textureId

        **GLuint QOpenGLTexture::textureId() const**

        Returns the name of the underlying OpenGL texture object or 0 if it has
        not yet been created.

        **See also** **create** (), **destroy** (), and **isCreated** ().
        """
        ...

    def isCreated(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#isCreated

        **bool QOpenGLTexture::isCreated() const**

        Returns `true` if the underlying OpenGL texture object has been created.

        **See also** **create** (), **destroy** (), and **textureId** ().
        """
        ...

    def destroy(self) -> None:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#destroy

        **void QOpenGLTexture::destroy()**

        Destroys the underlying OpenGL texture object. This requires a current
        valid OpenGL context.

        **See also** **create** (), **isCreated** (), and **textureId** ().
        """
        ...

    def create(self) -> bool:
        """
        https://doc.qt.io/qt-6/qopengltexture.html#create

        **bool QOpenGLTexture::create()**

        Creates the underlying OpenGL texture object. This requires a current
        valid OpenGL context. If the texture object already exists, this
        function does nothing.

        Once the texture object is created you can obtain the object name from
        the **textureId** () function. This may be useful if you wish to make
        some raw OpenGL calls related to this texture.

        Normally it should not be necessary to call this function directly as
        all functions that set properties of the texture object implicitly call
        create() on your behalf.

        Returns `true` if the creation succeeded, otherwise returns `false`.

        **See also** **destroy** (), **isCreated** (), and **textureId** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6 import QtGui
from PyQt6 import QtCore
from PyQt6.QtWidgets import *
import enum


class QTreeWidgetItem(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qtreewidgetitem.html

    **Detailed Description**

    Tree widget items are used to hold rows of information for tree widgets.
    Rows usually contain several columns of data, each of which can contain a
    text label and an icon.

    The QTreeWidgetItem class is a convenience class that replaces the
    QListViewItem class in Qt 3. It provides an item for use with the
    **QTreeWidget**  class.

    Items are usually constructed with a parent that is either a **QTreeWidget**
    (for top-level items) or a QTreeWidgetItem (for items on lower levels of the
    tree). For example, the following code constructs a top-level item to
    represent cities of the world, and adds a entry for Oslo as a child item:

    **QTreeWidgetItem**  *cities = new **QTreeWidgetItem** (treeWidget);
    cities->setText(0, tr("Cities"));
            **QTreeWidgetItem**  *osloItem =
    new **QTreeWidgetItem** (cities);
            osloItem->setText(0, tr("Oslo"));
    osloItem->setText(1, tr("Yes"));

    Items can be added in a particular order by specifying the item they follow
    when they are constructed:

    **QTreeWidgetItem**  *planets = new **QTreeWidgetItem** (treeWidget,
    cities);
            planets->setText(0, tr("Planets"));

    Each column in an item can have its own background brush which is set with
    the **setBackground** () function. The current background brush can be found
    with **background** (). The text label for each column can be rendered with
    its own font and brush. These are specified with the **setFont** () and
    **setForeground** () functions, and read with **font** () and **foreground**
    ().

    The main difference between top-level items and those in lower levels of the
    tree is that a top-level item has no **parent** (). This information can be
    used to tell the difference between items, and is useful to know when
    inserting and removing items from the tree. Children of an item can be
    removed with **takeChild** () and inserted at a given index in the list of
    children with the **insertChild** () function.

    By default, items are enabled, selectable, checkable, and can be the source
    of a drag and drop operation. Each item's flags can be changed by calling
    **setFlags** () with the appropriate value (see **Qt::ItemFlags** ).
    Checkable items can be checked and unchecked with the **setCheckState** ()
    function. The corresponding **checkState** () function indicates whether the
    item is currently checked.

    **Subclassing**

    When subclassing QTreeWidgetItem to provide custom items, it is possible to
    define new types for them so that they can be distinguished from standard
    items. The constructors for subclasses that require this feature need to
    call the base class constructor with a new type value equal to or greater
    than **UserType** .

    **See also** **QTreeWidget** , **QTreeWidgetItemIterator** , **Model/View
    Programming** , **QListWidgetItem** , and **QTableWidgetItem** .
    """

    class ChildIndicatorPolicy(enum.Enum):
        ShowIndicator: QTreeWidgetItem = ...
        DontShowIndicator: QTreeWidgetItem = ...
        DontShowIndicatorWhenChildless: QTreeWidgetItem = ...

    class ItemType(enum.IntEnum):
        Type: QTreeWidgetItem = ...
        UserType: QTreeWidgetItem = ...

    @typing.overload
    def __init__(
        self, parent: "QTreeWidgetItem", after: "QTreeWidgetItem", type: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem

        **QTreeWidgetItem::QTreeWidgetItem(int type = Type)**

        Constructs a tree widget item of the specified **type**. The item must
        be inserted into a tree widget.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(
        self, parent: "QTreeWidgetItem", strings: typing.Iterable[str], type: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-1

        **QTreeWidgetItem::QTreeWidgetItem(const QStringList & strings , int
        type = Type)**

        Constructs a tree widget item of the specified **type**. The item must
        be inserted into a tree widget. The given list of **strings** will be
        set as the item text for each column in the item.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: "QTreeWidgetItem", type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-2

        **QTreeWidgetItem::QTreeWidgetItem(QTreeWidget * parent , int type =
        Type)**

        Constructs a tree widget item of the specified **type** and appends it
        to the items in the given **parent**.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(
        self, parent: "QTreeWidget", after: "QTreeWidgetItem", type: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-3

        **QTreeWidgetItem::QTreeWidgetItem(QTreeWidget * parent , const
        QStringList & strings , int type = Type)**

        Constructs a tree widget item of the specified **type** and appends it
        to the items in the given **parent**. The given list of **strings** will
        be set as the item text for each column in the item.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(
        self, parent: "QTreeWidget", strings: typing.Iterable[str], type: int = ...
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-4

        **QTreeWidgetItem::QTreeWidgetItem(QTreeWidget * parent ,
        QTreeWidgetItem * preceding , int type = Type)**

        Constructs a tree widget item of the specified **type** and inserts it
        into the given **parent** after the **preceding** item.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, parent: "QTreeWidget", type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-5

        **QTreeWidgetItem::QTreeWidgetItem(QTreeWidgetItem * parent , int type =
        Type)**

        Constructs a tree widget item and append it to the given **parent**.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, strings: typing.Iterable[str], type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-6

        **QTreeWidgetItem::QTreeWidgetItem(QTreeWidgetItem * parent , const
        QStringList & strings , int type = Type)**

        Constructs a tree widget item and append it to the given **parent**. The
        given list of **strings** will be set as the item text for each column
        in the item.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, type: int = ...) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-7

        **QTreeWidgetItem::QTreeWidgetItem(QTreeWidgetItem * parent ,
        QTreeWidgetItem * preceding , int type = Type)**

        Constructs a tree widget item of the specified **type** that is inserted
        into the **parent** after the **preceding** child item.

        **See also** **type** ().
        """
        ...

    @typing.overload
    def __init__(self, other: "QTreeWidgetItem") -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#QTreeWidgetItem-8

        **QTreeWidgetItem::QTreeWidgetItem(const QTreeWidgetItem & other )**

        Constructs a copy of **other**. Note that **type** () and **treeWidget**
        () are not copied.

        This function is useful when reimplementing **clone** ().

        **See also** **data** () and **flags** ().
        """
        ...

    def emitDataChanged(self) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#emitDataChanged

        **[protected] void QTreeWidgetItem::emitDataChanged()**

        Causes the model associated with this item to emit a **dataChanged** ()
        signal for this item.

        You normally only need to call this function if you have subclassed
        **QTreeWidgetItem**  and reimplemented **data** () and/or **setData**
        ().

        **See also** **setData** ().
        """
        ...

    def isDisabled(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#isDisabled

        **bool QTreeWidgetItem::isDisabled() const**

        Returns `true` if the item is disabled; otherwise returns `false`.

        **See also** **setFlags** ().
        """
        ...

    def setDisabled(self, disabled: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setDisabled

        **void QTreeWidgetItem::setDisabled(bool disabled )**

        Disables the item if **disabled** is true; otherwise enables the item.

        **See also** **isDisabled** () and **setFlags** ().
        """
        ...

    def isFirstColumnSpanned(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#isFirstColumnSpanned

        **bool QTreeWidgetItem::isFirstColumnSpanned() const**

        Returns `true` if the item is spanning all the columns in a row;
        otherwise returns `false`.

        **See also** **setFirstColumnSpanned** ().
        """
        ...

    def setFirstColumnSpanned(self, aspan: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setFirstColumnSpanned

        **void QTreeWidgetItem::setFirstColumnSpanned(bool span )**

        Sets the first section to span all columns if **span** is true;
        otherwise all item sections are shown.

        **See also** **isFirstColumnSpanned** ().
        """
        ...

    def removeChild(self, child: "QTreeWidgetItem") -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#removeChild

        **void QTreeWidgetItem::removeChild(QTreeWidgetItem * child )**

        Removes the given item indicated by **child**. The removed item will not
        be deleted.
        """
        ...

    def childIndicatorPolicy(self) -> "QTreeWidgetItem.ChildIndicatorPolicy":
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#childIndicatorPolicy

        **QTreeWidgetItem::ChildIndicatorPolicy
        QTreeWidgetItem::childIndicatorPolicy() const**

        Returns the item indicator policy. This policy decides when the tree
        branch expand/collapse indicator is shown.

        **See also** **setChildIndicatorPolicy** ().
        """
        ...

    def setChildIndicatorPolicy(
        self, policy: "QTreeWidgetItem.ChildIndicatorPolicy"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setChildIndicatorPolicy

        **void QTreeWidgetItem::setChildIndicatorPolicy(QTreeWidgetItem::ChildIn
        dicatorPolicy policy )**

        Sets the item indicator **policy**. This policy decides when the tree
        branch expand/collapse indicator is shown. The default value is
        **DontShowIndicatorWhenChildless** .

        **See also** **childIndicatorPolicy** ().
        """
        ...

    def isExpanded(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#isExpanded

        **bool QTreeWidgetItem::isExpanded() const**

        Returns `true` if the item is expanded, otherwise returns `false`.

        **See also** **setExpanded** ().
        """
        ...

    def setExpanded(self, aexpand: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setExpanded

        **void QTreeWidgetItem::setExpanded(bool expand )**

        Expands the item if **expand** is true, otherwise collapses the item.

        **Warning:** The **QTreeWidgetItem**  must be added to the
        **QTreeWidget**  before calling this function.

        **See also** **isExpanded** ().
        """
        ...

    def isHidden(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#isHidden

        **bool QTreeWidgetItem::isHidden() const**

        Returns `true` if the item is hidden, otherwise returns `false`.

        **See also** **setHidden** ().
        """
        ...

    def setHidden(self, ahide: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setHidden

        **void QTreeWidgetItem::setHidden(bool hide )**

        Hides the item if **hide** is true, otherwise shows the item.

        **Note:** A call to this function has no effect if the item is not
        currently in a view. In particular, calling `setHidden(true)` on an item
        and only then adding it to a view will result in a visible item.

        **See also** **isHidden** ().
        """
        ...

    def isSelected(self) -> bool:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#isSelected

        **bool QTreeWidgetItem::isSelected() const**

        Returns `true` if the item is selected, otherwise returns `false`.

        **See also** **setSelected** ().
        """
        ...

    def setSelected(self, aselect: bool) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setSelected

        **void QTreeWidgetItem::setSelected(bool select )**

        Sets the selected state of the item to **select**.

        **See also** **isSelected** ().
        """
        ...

    def sortChildren(self, column: int, order: QtCore.Qt.SortOrder) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#sortChildren

        **void QTreeWidgetItem::sortChildren(int column , Qt::SortOrder order
        )**

        Sorts the children of the item using the given **order** , by the values
        in the given **column**.

        **Note:** This function does nothing if the item is not associated with
        a **QTreeWidget** .
        """
        ...

    def setForeground(
        self,
        column: int,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setForeground

        **void QTreeWidgetItem::setForeground(int column , const QBrush & brush
        )**

        Sets the foreground brush of the label in the given **column** to the
        specified **brush**.

        **See also** **foreground** () and **setBackground** ().
        """
        ...

    def foreground(self, column: int) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#foreground

        **QBrush QTreeWidgetItem::foreground(int column ) const**

        Returns the brush used to render the foreground (e.g. text) of the
        specified **column**. Setting a default-constructed brush will let the
        view use the default color from the style.

        **See also** **setForeground** () and **background** ().
        """
        ...

    def setBackground(
        self,
        column: int,
        brush: typing.Union[
            QtGui.QBrush, QtGui.QColor, QtCore.Qt.GlobalColor, int, QtGui.QGradient
        ],
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setBackground

        **void QTreeWidgetItem::setBackground(int column , const QBrush & brush
        )**

        Sets the background brush of the label in the given **column** to the
        specified **brush**. Setting a default-constructed brush will let the
        view use the default color from the style.

        **Note:** If **Qt Style Sheets**  are used on the same widget as
        setBackground(), style sheets will take precedence if the settings
        conflict.

        **See also** **background** () and **setForeground** ().
        """
        ...

    def background(self, column: int) -> QtGui.QBrush:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#background

        **QBrush QTreeWidgetItem::background(int column ) const**

        Returns the brush used to render the background of the specified
        **column**.

        **See also** **setBackground** () and **foreground** ().
        """
        ...

    def takeChildren(self) -> typing.List["QTreeWidgetItem"]:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#takeChildren

        **QList<QTreeWidgetItem *> QTreeWidgetItem::takeChildren()**

        Removes the list of children and returns it, otherwise returns an empty
        list.
        """
        ...

    def insertChildren(
        self, index: int, children: typing.Iterable["QTreeWidgetItem"]
    ) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#insertChildren

        **void QTreeWidgetItem::insertChildren(int index , const
        QList<QTreeWidgetItem *> & children )**

        Inserts the given list of **children** into the list of the item
        children at **index** .

        Children that have already been inserted somewhere else won't be
        inserted.
        """
        ...

    def addChildren(self, children: typing.Iterable["QTreeWidgetItem"]) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#addChildren

        **void QTreeWidgetItem::addChildren(const QList<QTreeWidgetItem *> &
        children )**

        Appends the given list of **children** to the item.

        **See also** **insertChildren** () and **takeChildren** ().
        """
        ...

    def setSizeHint(self, column: int, size: QtCore.QSize) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setSizeHint

        **void QTreeWidgetItem::setSizeHint(int column , const QSize & size )**

        Sets the size hint for the tree item in the given **column** to be
        **size**. If no size hint is set or **size** is invalid, the item
        delegate will compute the size hint based on the item data.

        **See also** **sizeHint** ().
        """
        ...

    def sizeHint(self, column: int) -> QtCore.QSize:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#sizeHint

        **QSize QTreeWidgetItem::sizeHint(int column ) const**

        Returns the size hint set for the tree item in the given **column** (see
        **QSize** ).

        **See also** **setSizeHint** ().
        """
        ...

    def indexOfChild(self, achild: "QTreeWidgetItem") -> int:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#indexOfChild

        **int QTreeWidgetItem::indexOfChild(QTreeWidgetItem * child ) const**

        Returns the index of the given **child** in the item's list of children.
        """
        ...

    def setFont(self, column: int, afont: QtGui.QFont) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setFont

        **void QTreeWidgetItem::setFont(int column , const QFont & font )**

        Sets the font used to display the text in the given **column** to the
        given **font**.

        **See also** **font** (), **setText** (), and **setForeground** ().
        """
        ...

    def setWhatsThis(self, column: int, awhatsThis: str) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setWhatsThis

        **void QTreeWidgetItem::setWhatsThis(int column , const QString &
        whatsThis )**

        Sets the "What's This?" help for the given **column** to **whatsThis**.

        **See also** **whatsThis** (), **setStatusTip** (), and **setToolTip**
        ().
        """
        ...

    def setToolTip(self, column: int, atoolTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setToolTip

        **void QTreeWidgetItem::setToolTip(int column , const QString & toolTip
        )**

        Sets the tooltip for the given **column** to **toolTip**.

        **See also** **toolTip** (), **setStatusTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setStatusTip(self, column: int, astatusTip: str) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setStatusTip

        **void QTreeWidgetItem::setStatusTip(int column , const QString &
        statusTip )**

        Sets the status tip for the given **column** to the given **statusTip**.
        **QTreeWidget**  mouse tracking needs to be enabled for this feature to
        work.

        **See also** **statusTip** (), **setToolTip** (), and **setWhatsThis**
        ().
        """
        ...

    def setIcon(self, column: int, aicon: QtGui.QIcon) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setIcon

        **void QTreeWidgetItem::setIcon(int column , const QIcon & icon )**

        Sets the icon to be displayed in the given **column** to **icon**.

        **See also** **icon** (), **setText** (), and **iconSize** .
        """
        ...

    def setText(self, column: int, atext: str) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setText

        **void QTreeWidgetItem::setText(int column , const QString & text )**

        Sets the text to be displayed in the given **column** to the given
        **text**.

        **See also** **text** (), **setFont** (), and **setForeground** ().
        """
        ...

    def setFlags(self, aflags: QtCore.Qt.ItemFlag) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setFlags

        **void QTreeWidgetItem::setFlags(Qt::ItemFlags flags )**

        Sets the flags for the item to the given **flags**. These determine
        whether the item can be selected or modified. This is often used to
        disable an item.

        **See also** **flags** ().
        """
        ...

    def type(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#type

        **int QTreeWidgetItem::type() const**

        Returns the type passed to the **QTreeWidgetItem**  constructor.
        """
        ...

    def takeChild(self, index: int) -> "QTreeWidgetItem":
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#takeChild

        **QTreeWidgetItem *QTreeWidgetItem::takeChild(int index )**

        Removes the item at **index** and returns it, otherwise return 0.
        """
        ...

    def insertChild(self, index: int, child: "QTreeWidgetItem") -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#insertChild

        **void QTreeWidgetItem::insertChild(int index , QTreeWidgetItem * child
        )**

        Inserts the **child** item at **index** in the list of children.

        If the child has already been inserted somewhere else it won't be
        inserted again.
        """
        ...

    def addChild(self, child: "QTreeWidgetItem") -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#addChild

        **void QTreeWidgetItem::addChild(QTreeWidgetItem * child )**

        Appends the **child** item to the list of children.

        **See also** **insertChild** () and **takeChild** ().
        """
        ...

    def columnCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#columnCount

        **int QTreeWidgetItem::columnCount() const**

        Returns the number of columns in the item.
        """
        ...

    def childCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#childCount

        **int QTreeWidgetItem::childCount() const**

        Returns the number of child items.
        """
        ...

    def child(self, index: int) -> "QTreeWidgetItem":
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#child

        **QTreeWidgetItem *QTreeWidgetItem::child(int index ) const**

        Returns the item at the given **index** in the list of the item's
        children.

        **See also** **parent** ().
        """
        ...

    def parent(self) -> "QTreeWidgetItem":
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#parent

        **QTreeWidgetItem *QTreeWidgetItem::parent() const**

        Returns the item's parent.

        **See also** **child** ().
        """
        ...

    def write(self, out: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#write

        **[virtual] void QTreeWidgetItem::write(QDataStream & out ) const**

        Writes the item to stream **out**. This only writes data from one single
        item.

        **See also** **read** ().
        """
        ...

    def read(self, in_: QtCore.QDataStream) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#read

        **[virtual] void QTreeWidgetItem::read(QDataStream & in )**

        Reads the item from stream **in**. This only reads data into a single
        item.

        **See also** **write** ().
        """
        ...

    def setData(self, column: int, role: int, value: typing.Any) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setData

        **[virtual] void QTreeWidgetItem::setData(int column , int role , const
        QVariant & value )**

        Sets the value for the item's **column** and **role** to the given
        **value**.

        The **role** describes the type of data specified by **value** , and is
        defined by the **Qt::ItemDataRole**  enum.

        **Note:** The default implementation treats **Qt::EditRole**  and
        **Qt::DisplayRole**  as referring to the same data.

        **See also** **data** ().
        """
        ...

    def data(self, column: int, role: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#data

        **[virtual] QVariant QTreeWidgetItem::data(int column , int role )
        const**

        Returns the value for the item's **column** and **role**.

        **See also** **setData** ().
        """
        ...

    def setCheckState(self, column: int, state: QtCore.Qt.CheckState) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setCheckState

        **void QTreeWidgetItem::setCheckState(int column , Qt::CheckState state
        )**

        Sets the item in the given **column** check state to be **state**.

        **See also** **checkState** ().
        """
        ...

    def checkState(self, column: int) -> QtCore.Qt.CheckState:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#checkState

        **Qt::CheckState QTreeWidgetItem::checkState(int column ) const**

        Returns the check state of the label in the given **column**.

        **See also** **setCheckState** () and **Qt::CheckState** .
        """
        ...

    def setTextAlignment(self, column: int, alignment: int) -> None:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#setTextAlignment

        **void QTreeWidgetItem::setTextAlignment(int column , int alignment )**

        Sets the text alignment for the label in the given **column** to the
        **alignment** specified (see **Qt::AlignmentFlag** ).

        **See also** **textAlignment** ().
        """
        ...

    def textAlignment(self, column: int) -> int:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#textAlignment

        **int QTreeWidgetItem::textAlignment(int column ) const**

        Returns the text alignment for the label in the given **column** (see
        **Qt::AlignmentFlag** ).

        **See also** **setTextAlignment** ().
        """
        ...

    def font(self, column: int) -> QtGui.QFont:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#font

        **QFont QTreeWidgetItem::font(int column ) const**

        Returns the font used to render the text in the specified **column**.

        **See also** **setFont** ().
        """
        ...

    def whatsThis(self, column: int) -> str:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#whatsThis

        **QString QTreeWidgetItem::whatsThis(int column ) const**

        Returns the "What's This?" help for the contents of the given
        **column**.

        **See also** **setWhatsThis** ().
        """
        ...

    def toolTip(self, column: int) -> str:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#toolTip

        **QString QTreeWidgetItem::toolTip(int column ) const**

        Returns the tool tip for the given **column**.

        **See also** **setToolTip** ().
        """
        ...

    def statusTip(self, column: int) -> str:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#statusTip

        **QString QTreeWidgetItem::statusTip(int column ) const**

        Returns the status tip for the contents of the given **column**.

        **See also** **setStatusTip** ().
        """
        ...

    def icon(self, column: int) -> QtGui.QIcon:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#icon

        **QIcon QTreeWidgetItem::icon(int column ) const**

        Returns the icon that is displayed in the specified **column**.

        **See also** **setIcon** () and **iconSize** .
        """
        ...

    def text(self, column: int) -> str:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#text

        **QString QTreeWidgetItem::text(int column ) const**

        Returns the text in the specified **column**.

        **See also** **setText** ().
        """
        ...

    def flags(self) -> QtCore.Qt.ItemFlag:
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#flags

        **Qt::ItemFlags QTreeWidgetItem::flags() const**

        Returns the flags used to describe the item. These determine whether the
        item can be checked, edited, and selected.

        The default value for flags is **Qt::ItemIsSelectable**  |
        **Qt::ItemIsUserCheckable**  | **Qt::ItemIsEnabled**  |
        **Qt::ItemIsDragEnabled**  | **Qt::ItemIsDropEnabled** .

        **See also** **setFlags** ().
        """
        ...

    def treeWidget(self) -> "QTreeWidget":
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#treeWidget

        **QTreeWidget *QTreeWidgetItem::treeWidget() const**

        Returns the tree widget that contains the item.
        """
        ...

    def clone(self) -> "QTreeWidgetItem":
        """
        https://doc.qt.io/qt-6/qtreewidgetitem.html#clone

        **[virtual] QTreeWidgetItem *QTreeWidgetItem::clone() const**

        Creates a deep copy of the item and of its children.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
import PyQt6.sip
from PyQt6.QtNetwork import *


class QSslCipher(PyQt6.sip.simplewrapper):
    """
    https://doc.qt.io/qt-6/qsslcipher.html

    **Detailed Description**

    QSslCipher stores information about one cryptographic cipher. It is most
    commonly used with **QSslSocket** , either for configuring which ciphers the
    socket can use, or for displaying the socket's ciphers to the user.

    **See also** **QSslSocket**  and **QSslKey** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#QSslCipher

        **QSslCipher::QSslCipher()**

        Constructs an empty QSslCipher object.
        """
        ...

    @typing.overload
    def __init__(self, name: str) -> None:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#QSslCipher-1

        **[since 5.3] QSslCipher::QSslCipher(const QString & name )**

        Constructs a QSslCipher object for the cipher determined by **name**.
        The constructor accepts only supported ciphers (i.e., the **name** must
        identify a cipher in the list of ciphers returned by
        QSslSocket::supportedCiphers()).

        You can call **isNull** () after construction to check if **name**
        correctly identified a supported cipher.

        This function was introduced in Qt 5.3.
        """
        ...

    @typing.overload
    def __init__(self, name: str, protocol: QSsl.SslProtocol) -> None:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#QSslCipher-2

        **QSslCipher::QSslCipher(const QString & name , QSsl::SslProtocol
        protocol )**

        Constructs a QSslCipher object for the cipher determined by **name** and
        **protocol**. The constructor accepts only supported ciphers (i.e., the
        **name** and **protocol** must identify a cipher in the list of ciphers
        returned by QSslSocket::supportedCiphers()).

        You can call **isNull** () after construction to check if **name** and
        **protocol** correctly identified a supported cipher.
        """
        ...

    @typing.overload
    def __init__(self, other: "QSslCipher") -> None:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#QSslCipher-3

        **QSslCipher::QSslCipher(const QSslCipher & other )**

        Constructs an identical copy of the **other** cipher.
        """
        ...

    def swap(self, other: "QSslCipher") -> None:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#swap

        **[since 5.0] void QSslCipher::swap(QSslCipher & other )**

        Swaps this cipher instance with **other**. This function is very fast
        and never fails.

        This function was introduced in Qt 5.0.
        """
        ...

    def protocol(self) -> QSsl.SslProtocol:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#protocol

        **QSsl::SslProtocol QSslCipher::protocol() const**

        Returns the cipher's protocol type, or **QSsl::UnknownProtocol**  if
        **QSslCipher**  is unable to determine the protocol (**protocolString**
        () may contain more information).

        **See also** **protocolString** ().
        """
        ...

    def protocolString(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#protocolString

        **QString QSslCipher::protocolString() const**

        Returns the cipher's protocol as a **QString** .

        **See also** **protocol** ().
        """
        ...

    def encryptionMethod(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#encryptionMethod

        **QString QSslCipher::encryptionMethod() const**

        Returns the cipher's encryption method as a **QString** .
        """
        ...

    def authenticationMethod(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#authenticationMethod

        **QString QSslCipher::authenticationMethod() const**

        Returns the cipher's authentication method as a **QString** .
        """
        ...

    def keyExchangeMethod(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#keyExchangeMethod

        **QString QSslCipher::keyExchangeMethod() const**

        Returns the cipher's key exchange method as a **QString** .
        """
        ...

    def usedBits(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#usedBits

        **int QSslCipher::usedBits() const**

        Returns the number of bits used by the cipher.

        **See also** **supportedBits** ().
        """
        ...

    def supportedBits(self) -> int:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#supportedBits

        **int QSslCipher::supportedBits() const**

        Returns the number of bits supported by the cipher.

        **See also** **usedBits** ().
        """
        ...

    def name(self) -> str:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#name

        **QString QSslCipher::name() const**

        Returns the name of the cipher, or an empty **QString**  if this is a
        null cipher.

        **See also** **isNull** ().
        """
        ...

    def isNull(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsslcipher.html#isNull

        **bool QSslCipher::isNull() const**

        Returns `true` if this is a null cipher; otherwise returns `false`.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import typing
from PyQt6 import QtCore
from PyQt6.QtGui import *


class QRadialGradient(QGradient):
    """
    https://doc.qt.io/qt-6/qradialgradient.html

    **Detailed Description**

    Qt supports both simple and extended radial gradients.

    Simple radial gradients interpolate colors between a focal point and end
    points on a circle surrounding it. Extended radial gradients interpolate
    colors between a focal circle and a center circle. Points outside the cone
    defined by the two circles will be transparent. For simple radial gradients
    the focal point is adjusted to lie inside the center circle, whereas the
    focal point can have any position in an extended radial gradient.

    Outside the end points the gradient is either padded, reflected or repeated
    depending on the currently set **spread**  method:

    ![](images/qradialgradient-pad.png)![](images/qradialgradient-
    reflect.png)![](images/qradialgradient-repeat.png)
    **PadSpread**
    (default)**ReflectSpread** **RepeatSpread**

    The colors in a gradient is defined using stop points of the
    **QGradientStop**  type, i.e. a position and a color. Use the
    **QGradient::setColorAt** () or the **QGradient::setStops** () function to
    define the stop points. It is the gradient's complete set of stop points
    that describes how the gradient area should be filled. If no stop points
    have been specified, a gradient of black at 0 to white at 1 is used.

    In addition to the functions inherited from **QGradient** , the
    QRadialGradient class provides the **center** (), **focalPoint** () and
    **radius** () functions returning the gradient's center, focal point and
    radius respectively.

    **See also** **QLinearGradient** , **QConicalGradient** , and **The
    Gradients Example** .
    """

    @typing.overload
    def __init__(self) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient

        **QRadialGradient::QRadialGradient()**

        Constructs a simple radial gradient with the center and focal point at
        (0, 0) with a radius of 1.
        """
        ...

    @typing.overload
    def __init__(
        self, center: QtCore.QPointF, radius: float, focalPoint: QtCore.QPointF
    ) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient-1

        **QRadialGradient::QRadialGradient(const QPointF & center , qreal radius
        , const QPointF & focalPoint )**

        Constructs a simple radial gradient with the given **center** ,
        **radius** and **focalPoint**.

        **Note:** If the given focal point is outside the circle defined by the
        **center** point and **radius** , it will be re-adjusted to lie at a
        point on the circle where it intersects with the line from **center** to
        **focalPoint**.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        center: QtCore.QPointF,
        centerRadius: float,
        focalPoint: QtCore.QPointF,
        focalRadius: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient-2

        **QRadialGradient::QRadialGradient(qreal cx , qreal cy , qreal radius ,
        qreal fx , qreal fy )**

        Constructs a simple radial gradient with the given center ( **cx** ,
        **cy** ), **radius** and focal point ( **fx** , **fy** ).

        **Note:** If the given focal point is outside the circle defined by the
        center ( **cx** , **cy** ) and the **radius** it will be re-adjusted to
        the intersection between the line from the center to the focal point and
        the circle.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(self, center: QtCore.QPointF, radius: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient-3

        **QRadialGradient::QRadialGradient(const QPointF & center , qreal radius
        )**

        Constructs a simple radial gradient with the given **center** ,
        **radius** and the focal point in the circle center.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(
        self, cx: float, cy: float, radius: float, fx: float, fy: float
    ) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient-4

        **QRadialGradient::QRadialGradient(qreal cx , qreal cy , qreal radius
        )**

        Constructs a simple radial gradient with the center at ( **cx** , **cy**
        ) and the specified **radius**. The focal point lies at the center of
        the circle.

        **See also** **QGradient::setColorAt** () and **QGradient::setStops**
        ().
        """
        ...

    @typing.overload
    def __init__(
        self,
        cx: float,
        cy: float,
        centerRadius: float,
        fx: float,
        fy: float,
        focalRadius: float,
    ) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient-5

        **QRadialGradient::QRadialGradient(const QPointF & center , qreal
        centerRadius , const QPointF & focalPoint , qreal focalRadius )**

        Constructs an extended radial gradient with the given **center** ,
        **centerRadius** , **focalPoint** , and **focalRadius**.
        """
        ...

    @typing.overload
    def __init__(self, cx: float, cy: float, radius: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient-6

        **QRadialGradient::QRadialGradient(qreal cx , qreal cy , qreal
        centerRadius , qreal fx , qreal fy , qreal focalRadius )**

        Constructs an extended radial gradient with the given center ( **cx** ,
        **cy** ), center radius, **centerRadius** , focal point, ( **fx** ,
        **fy** ), and focal radius **focalRadius**.
        """
        ...

    @typing.overload
    def __init__(self, a0: "QRadialGradient") -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#QRadialGradient

        **QRadialGradient::QRadialGradient()**

        Constructs a simple radial gradient with the center and focal point at
        (0, 0) with a radius of 1.
        """
        ...

    def setFocalRadius(self, radius: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setFocalRadius

        **void QRadialGradient::setFocalRadius(qreal radius )**

        Sets the focal radius of this radial gradient in logical coordinates to
        **radius**

        **See also** **focalRadius** ().
        """
        ...

    def focalRadius(self) -> float:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#focalRadius

        **qreal QRadialGradient::focalRadius() const**

        Returns the focal radius of this radial gradient in logical coordinates.

        **See also** **setFocalRadius** () and **QGradient::stops** ().
        """
        ...

    def setCenterRadius(self, radius: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setCenterRadius

        **void QRadialGradient::setCenterRadius(qreal radius )**

        Sets the center radius of this radial gradient in logical coordinates to
        **radius**

        **See also** **centerRadius** ().
        """
        ...

    def centerRadius(self) -> float:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#centerRadius

        **qreal QRadialGradient::centerRadius() const**

        Returns the center radius of this radial gradient in logical
        coordinates.

        **See also** **setCenterRadius** () and **QGradient::stops** ().
        """
        ...

    def setRadius(self, radius: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setRadius

        **void QRadialGradient::setRadius(qreal radius )**

        Sets the radius of this radial gradient in logical coordinates to
        **radius**

        Equivalent to **setCenterRadius** ()

        **See also** **radius** ().
        """
        ...

    @typing.overload
    def setFocalPoint(self, focalPoint: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setFocalPoint

        **void QRadialGradient::setFocalPoint(const QPointF & focalPoint )**

        Sets the focal point of this radial gradient in logical coordinates to
        **focalPoint**.

        **See also** **focalPoint** ().
        """
        ...

    @typing.overload
    def setFocalPoint(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setFocalPoint-1

        **void QRadialGradient::setFocalPoint(qreal x , qreal y )**

        This is an overloaded function.

        Sets the focal point of this radial gradient in logical coordinates to (
        **x** , **y** ).

        **See also** **focalPoint** ().
        """
        ...

    @typing.overload
    def setCenter(self, center: QtCore.QPointF) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setCenter

        **void QRadialGradient::setCenter(const QPointF & center )**

        Sets the center of this radial gradient in logical coordinates to
        **center**.

        **See also** **center** ().
        """
        ...

    @typing.overload
    def setCenter(self, x: float, y: float) -> None:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#setCenter-1

        **void QRadialGradient::setCenter(qreal x , qreal y )**

        This is an overloaded function.

        Sets the center of this radial gradient in logical coordinates to (
        **x** , **y** ).

        **See also** **center** ().
        """
        ...

    def radius(self) -> float:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#radius

        **qreal QRadialGradient::radius() const**

        Returns the radius of this radial gradient in logical coordinates.

        Equivalent to **centerRadius** ()

        **See also** **setRadius** () and **QGradient::stops** ().
        """
        ...

    def focalPoint(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#focalPoint

        **QPointF QRadialGradient::focalPoint() const**

        Returns the focal point of this radial gradient in logical coordinates.

        **See also** **setFocalPoint** () and **QGradient::stops** ().
        """
        ...

    def center(self) -> QtCore.QPointF:
        """
        https://doc.qt.io/qt-6/qradialgradient.html#center

        **QPointF QRadialGradient::center() const**

        Returns the center of this radial gradient in logical coordinates.

        **See also** **setCenter** () and **QGradient::stops** ().
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import PyQt6.sip
from PyQt6 import QtWidgets
from PyQt6 import QtCore


class QHelpContentWidget(QtWidgets.QTreeView):
    """
    https://doc.qt.io/qt-6/qhelpcontentwidget.html

    **Detailed Description**
    """

    def indexOf(self, link: QtCore.QUrl) -> QtCore.QModelIndex:
        """
        https://doc.qt.io/qt-6/qhelpcontentwidget.html#indexOf

        **QModelIndex QHelpContentWidget::indexOf(const QUrl & link )**

        Returns the index of the content item with the **link**. An invalid
        index is returned if no such an item exists.
        """
        ...

    @property
    def linkActivated(self) -> PyQt6.QtCore.pyqtBoundSignal:
        """
        https://doc.qt.io/qt-6/qhelpcontentwidget.html#linkActivated

        **[signal] void QHelpContentWidget::linkActivated(const QUrl & link )**

        This signal is emitted when a content item is activated and its
        associated **link** should be shown.
        """
        ...



"""
PySide stub files generated by **IceSpringPySideStubs**

Home: https://baijifeilong.github.io/2022/01/06/ice-spring-pyside-stubs/index.html

Github: https://github.com/baijifeilong/IceSpringPySideStubs

PyPI(PySide2): https://pypi.org/project/IceSpringPySideStubs-PySide2

PyPI(PySide6): https://pypi.org/project/IceSpringPySideStubs-PySide6

PyPI(PyQt5): https://pypi.org/project/IceSpringPySideStubs-PyQt5

PyPI(PyQt6): https://pypi.org/project/IceSpringPySideStubs-PyQt6

Generated by BaiJiFeiLong@gmail.com

License: MIT
"""
import enum
import typing
import PyQt6.sip
from PyQt6.QtSql import *
import enum


class QSqlResult(PyQt6.sip.wrapper):
    """
    https://doc.qt.io/qt-6/qsqlresult.html

    **Detailed Description**

    Normally, you would use **QSqlQuery**  instead of QSqlResult, since
    **QSqlQuery**  provides a generic wrapper for database-specific
    implementations of QSqlResult.

    If you are implementing your own SQL driver (by subclassing **QSqlDriver**
    ), you will need to provide your own QSqlResult subclass that implements all
    the pure virtual functions and other virtual functions that you need.

    **See also** **QSqlDriver** .
    """

    class BindingSyntax(enum.Enum):
        PositionalBinding: QSqlResult = ...
        NamedBinding: QSqlResult = ...

    def __init__(self, db: QSqlDriver) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#QSqlResult

        **[protected] QSqlResult::QSqlResult(const QSqlDriver * db )**

        Creates a QSqlResult using database driver **db**. The object is
        initialized to an inactive state.

        **See also** **isActive** () and **driver** ().
        """
        ...

    def lastInsertId(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#lastInsertId

        **[virtual protected] QVariant QSqlResult::lastInsertId() const**

        Returns the object ID of the most recent inserted row if the database
        supports it. An invalid **QVariant**  will be returned if the query did
        not insert any value or if the database does not report the id back. If
        more than one row was touched by the insert, the behavior is undefined.

        Note that for Oracle databases the row's ROWID will be returned, while
        for MySQL databases the row's auto-increment field will be returned.

        **See also** **QSqlDriver::hasFeature** ().
        """
        ...

    def record(self) -> QSqlRecord:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#record

        **[virtual protected] QSqlRecord QSqlResult::record() const**

        Returns the current record if the query is active; otherwise returns an
        empty **QSqlRecord** .

        The default implementation always returns an empty **QSqlRecord** .

        **See also** **isActive** ().
        """
        ...

    def numRowsAffected(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#numRowsAffected

        **[pure virtual protected] int QSqlResult::numRowsAffected()**

        Returns the number of rows affected by the last query executed, or -1 if
        it cannot be determined or if the query is a `SELECT` statement.

        **See also** **size** ().
        """
        ...

    def size(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#size

        **[pure virtual protected] int QSqlResult::size()**

        Returns the size of the `SELECT` result, or -1 if it cannot be
        determined or if the query is not a `SELECT` statement.

        **See also** **numRowsAffected** ().
        """
        ...

    def fetchLast(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#fetchLast

        **[pure virtual protected] bool QSqlResult::fetchLast()**

        Positions the result to the last record (last row) in the result.

        This function is only called if the result is in an active state.
        Derived classes must reimplement this function and position the result
        to the last record, and call **setAt** () with an appropriate value.
        Return true to indicate success, or false to signify failure.

        **See also** **fetch** () and **fetchFirst** ().
        """
        ...

    def fetchFirst(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#fetchFirst

        **[pure virtual protected] bool QSqlResult::fetchFirst()**

        Positions the result to the first record (row 0) in the result.

        This function is only called if the result is in an active state.
        Derived classes must reimplement this function and position the result
        to the first record, and call **setAt** () with an appropriate value.
        Return true to indicate success, or false to signify failure.

        **See also** **fetch** () and **fetchLast** ().
        """
        ...

    def fetchPrevious(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#fetchPrevious

        **[virtual protected] bool QSqlResult::fetchPrevious()**

        Positions the result to the previous record (row) in the result.

        This function is only called if the result is in an active state. The
        default implementation calls **fetch** () with the previous index.
        Derived classes can reimplement this function and position the result to
        the next record in some other way, and call **setAt** () with an
        appropriate value. Return true to indicate success, or false to signify
        failure.
        """
        ...

    def fetchNext(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#fetchNext

        **[virtual protected] bool QSqlResult::fetchNext()**

        Positions the result to the next available record (row) in the result.

        This function is only called if the result is in an active state. The
        default implementation calls **fetch** () with the next index. Derived
        classes can reimplement this function and position the result to the
        next record in some other way, and call **setAt** () with an appropriate
        value. Return true to indicate success, or false to signify failure.

        **See also** **fetch** () and **fetchPrevious** ().
        """
        ...

    def fetch(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#fetch

        **[pure virtual protected] bool QSqlResult::fetch(int index )**

        Positions the result to an arbitrary (zero-based) row **index**.

        This function is only called if the result is in an active state.
        Derived classes must reimplement this function and position the result
        to the row **index** , and call **setAt** () with an appropriate value.
        Return true to indicate success, or false to signify failure.

        **See also** **isActive** (), **fetchFirst** (), **fetchLast** (),
        **fetchNext** (), and **fetchPrevious** ().
        """
        ...

    def reset(self, sqlquery: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#reset

        **[pure virtual protected] bool QSqlResult::reset(const QString & query
        )**

        Sets the result to use the SQL statement **query** for subsequent data
        retrieval.

        Derived classes must reimplement this function and apply the **query**
        to the database. This function is only called after the result is set to
        an inactive state and is positioned before the first record of the new
        result. Derived classes should return true if the query was successful
        and ready to be used, or false otherwise.

        **See also** **setQuery** ().
        """
        ...

    def isNull(self, i: int) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#isNull

        **[pure virtual protected] bool QSqlResult::isNull(int index )**

        Returns `true` if the field at position **index** in the current row is
        null; otherwise returns `false`.
        """
        ...

    def data(self, i: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#data

        **[pure virtual protected] QVariant QSqlResult::data(int index )**

        Returns the data for field **index** in the current row as a
        **QVariant** . This function is only called if the result is in an
        active state and is positioned on a valid record and **index** is non-
        negative. Derived classes must reimplement this function and return the
        value of field **index** , or QVariant() if it cannot be determined.
        """
        ...

    def bindingSyntax(self) -> "QSqlResult.BindingSyntax":
        """
        https://doc.qt.io/qt-6/qsqlresult.html#bindingSyntax

        **[protected] QSqlResult::BindingSyntax QSqlResult::bindingSyntax()
        const**

        Returns the binding syntax used by prepared queries.
        """
        ...

    def hasOutValues(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#hasOutValues

        **[protected] bool QSqlResult::hasOutValues() const**

        Returns `true` if at least one of the query's bound values is a
        `QSql::Out` or a **QSql::InOut** ; otherwise returns `false`.

        **See also** **bindValueType** ().
        """
        ...

    def clear(self) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#clear

        **[protected] void QSqlResult::clear()**

        Clears the entire result set and releases any associated resources.
        """
        ...

    def boundValueName(self, pos: int) -> str:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#boundValueName

        **[protected] QString QSqlResult::boundValueName(int index ) const**

        Returns the name of the bound value at position **index** in the current
        record (row).

        **See also** **boundValue** ().
        """
        ...

    def executedQuery(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#executedQuery

        **[protected] QString QSqlResult::executedQuery() const**

        Returns the query that was actually executed. This may differ from the
        query that was passed, for example if bound values were used with a
        prepared query and the underlying database doesn't support prepared
        queries.

        **See also** **exec** () and **setQuery** ().
        """
        ...

    def boundValues(self) -> typing.List[typing.Any]:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#boundValues

        **[protected] QList<QVariant> &QSqlResult::boundValues() const**

        Returns a vector of the result's bound values for the current record
        (row).

        **See also** **boundValueCount** ().
        """
        ...

    def boundValueCount(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#boundValueCount

        **[protected] int QSqlResult::boundValueCount() const**

        Returns the number of bound values in the result.

        **See also** **boundValues** ().
        """
        ...

    @typing.overload
    def bindValueType(self, placeholder: str) -> "QSql.ParamTypeFlag":
        """
        https://doc.qt.io/qt-6/qsqlresult.html#bindValueType

        **[protected] QSql::ParamType QSqlResult::bindValueType(int index )
        const**

        Returns the parameter type for the value bound at position **index**.

        **See also** **boundValue** ().
        """
        ...

    @typing.overload
    def bindValueType(self, pos: int) -> "QSql.ParamTypeFlag":
        """
        https://doc.qt.io/qt-6/qsqlresult.html#bindValueType-1

        **[protected] QSql::ParamType QSqlResult::bindValueType(const QString &
        placeholder ) const**

        This is an overloaded function.

        Returns the parameter type for the value bound with the given
        **placeholder** name.
        """
        ...

    @typing.overload
    def boundValue(self, placeholder: str) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#boundValue

        **[protected] QVariant QSqlResult::boundValue(int index ) const**

        Returns the value bound at position **index** in the current record
        (row).

        **See also** **bindValue** () and **boundValues** ().
        """
        ...

    @typing.overload
    def boundValue(self, pos: int) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#boundValue-1

        **[protected] QVariant QSqlResult::boundValue(const QString &
        placeholder ) const**

        This is an overloaded function.

        Returns the value bound by the given **placeholder** name in the current
        record (row).

        **See also** **bindValueType** ().
        """
        ...

    def addBindValue(self, val: typing.Any, type: "QSql.ParamTypeFlag") -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#addBindValue

        **[protected] void QSqlResult::addBindValue(const QVariant & val ,
        QSql::ParamType paramType )**

        Binds the value **val** of parameter type **paramType** to the next
        available position in the current record (row).

        **See also** **bindValue** ().
        """
        ...

    @typing.overload
    def bindValue(self, pos: int, val: typing.Any, type: "QSql.ParamTypeFlag") -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#bindValue

        **[virtual protected] void QSqlResult::bindValue(int index , const
        QVariant & val , QSql::ParamType paramType )**

        Binds the value **val** of parameter type **paramType** to position
        **index** in the current record (row).

        **See also** **addBindValue** ().
        """
        ...

    @typing.overload
    def bindValue(
        self, placeholder: str, val: typing.Any, type: "QSql.ParamTypeFlag"
    ) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#bindValue-1

        **[virtual protected] void QSqlResult::bindValue(const QString &
        placeholder , const QVariant & val , QSql::ParamType paramType )**

        This is an overloaded function.

        Binds the value **val** of parameter type **paramType** to the
        **placeholder** name in the current record (row).

        **Note:** Binding an undefined placeholder will result in undefined
        behavior.

        **See also** **QSqlQuery::bindValue** ().
        """
        ...

    def savePrepare(self, sqlquery: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#savePrepare

        **[virtual protected] bool QSqlResult::savePrepare(const QString & query
        )**

        Prepares the given **query** , using the underlying database
        functionality where possible. Returns `true` if the query is prepared
        successfully; otherwise returns `false`.

        Note: This method should have been called "safePrepare()".

        **See also** **prepare** ().
        """
        ...

    def prepare(self, query: str) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#prepare

        **[virtual protected] bool QSqlResult::prepare(const QString & query )**

        Prepares the given **query** for execution; the query will normally use
        placeholders so that it can be executed repeatedly. Returns true if the
        query is prepared successfully; otherwise returns `false`.

        **See also** **exec** ().
        """
        ...

    def exec(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#exec

        **[virtual protected] bool QSqlResult::exec()**

        Executes the query, returning true if successful; otherwise returns
        false.

        **See also** **prepare** ().
        """
        ...

    def setForwardOnly(self, forward: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#setForwardOnly

        **[virtual protected] void QSqlResult::setForwardOnly(bool forward )**

        Sets forward only mode to **forward**. If **forward** is true, only
        **fetchNext** () is allowed for navigating the results. Forward only
        mode needs much less memory since results do not have to be cached. By
        default, this feature is disabled.

        Setting forward only to false is a suggestion to the database engine,
        which has the final say on whether a result set is forward only or
        scrollable. **isForwardOnly** () will always return the correct status
        of the result set.

        **Note:** Calling setForwardOnly after execution of the query will
        result in unexpected results at best, and crashes at worst.

        **Note:** To make sure the forward-only query completed successfully,
        the application should check **lastError** () for an error not only
        after executing the query, but also after navigating the query results.

        **Warning:** PostgreSQL: While navigating the query results in forward-
        only mode, do not execute any other SQL command on the same database
        connection. This will cause the query results to be lost.

        **See also** **isForwardOnly** (), **fetchNext** (), and
        **QSqlQuery::setForwardOnly** ().
        """
        ...

    def setSelect(self, s: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#setSelect

        **[virtual protected] void QSqlResult::setSelect(bool select )**

        This function is provided for derived classes to indicate whether or not
        the current statement is a SQL `SELECT` statement. The **select**
        parameter should be true if the statement is a `SELECT` statement;
        otherwise it should be false.

        **See also** **isSelect** ().
        """
        ...

    def setQuery(self, query: str) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#setQuery

        **[virtual protected] void QSqlResult::setQuery(const QString & query
        )**

        Sets the current query for the result to **query**. You must call
        **reset** () to execute the query on the database.

        **See also** **reset** () and **lastQuery** ().
        """
        ...

    def setLastError(self, e: QSqlError) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#setLastError

        **[virtual protected] void QSqlResult::setLastError(const QSqlError &
        error )**

        This function is provided for derived classes to set the last error to
        **error**.

        **See also** **lastError** ().
        """
        ...

    def setActive(self, a: bool) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#setActive

        **[virtual protected] void QSqlResult::setActive(bool active )**

        This function is provided for derived classes to set the internal active
        state to **active**.

        **See also** **isActive** ().
        """
        ...

    def setAt(self, at: int) -> None:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#setAt

        **[virtual protected] void QSqlResult::setAt(int index )**

        This function is provided for derived classes to set the internal (zero-
        based) row position to **index**.

        **See also** **at** ().
        """
        ...

    def driver(self) -> QSqlDriver:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#driver

        **[protected] const QSqlDriver *QSqlResult::driver() const**

        Returns the driver associated with the result. This is the object that
        was passed to the constructor.
        """
        ...

    def isForwardOnly(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#isForwardOnly

        **[protected] bool QSqlResult::isForwardOnly() const**

        Returns `true` if you can only scroll forward through the result set;
        otherwise returns `false`.

        **See also** **setForwardOnly** ().
        """
        ...

    def isSelect(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#isSelect

        **[protected] bool QSqlResult::isSelect() const**

        Returns `true` if the current result is from a `SELECT` statement;
        otherwise returns `false`.

        **See also** **setSelect** ().
        """
        ...

    def isActive(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#isActive

        **[protected] bool QSqlResult::isActive() const**

        Returns `true` if the result has records to be retrieved; otherwise
        returns `false`.
        """
        ...

    def isValid(self) -> bool:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#isValid

        **[protected] bool QSqlResult::isValid() const**

        Returns `true` if the result is positioned on a valid record (that is,
        the result is not positioned before the first or after the last record);
        otherwise returns `false`.

        **See also** **at** ().
        """
        ...

    def lastError(self) -> QSqlError:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#lastError

        **[protected] QSqlError QSqlResult::lastError() const**

        Returns the last error associated with the result.

        **See also** **setLastError** ().
        """
        ...

    def lastQuery(self) -> str:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#lastQuery

        **[protected] QString QSqlResult::lastQuery() const**

        Returns the current SQL query text, or an empty string if there isn't
        one.

        **See also** **setQuery** ().
        """
        ...

    def at(self) -> int:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#at

        **[protected] int QSqlResult::at() const**

        Returns the current (zero-based) row position of the result. May return
        the special values **QSql::BeforeFirstRow**  or **QSql::AfterLastRow** .

        **See also** **setAt** () and **isValid** ().
        """
        ...

    def handle(self) -> typing.Any:
        """
        https://doc.qt.io/qt-6/qsqlresult.html#handle

        **[virtual] QVariant QSqlResult::handle() const**

        Returns the low-level database handle for this result set wrapped in a
        **QVariant**  or an invalid **QVariant**  if there is no handle.

        **Warning:** Use this with uttermost care and only if you know what
        you're doing.

        **Warning:** The handle returned here can become a stale pointer if the
        result is modified (for example, if you clear it).

        **Warning:** The handle can be NULL if the result was not executed yet.

        **Warning:** PostgreSQL: in forward-only mode, the handle of
        **QSqlResult**  can change after calling **fetch** (), **fetchFirst**
        (), **fetchLast** (), **fetchNext** (), **fetchPrevious** (),
        nextResult().

        The handle returned here is database-dependent, you should query the
        type name of the variant before accessing it.

        This example retrieves the handle for a sqlite result:

        **QSqlDatabase**  db = **QSqlDatabase** ::database("sales");
        **QSqlQuery**  query("SELECT NAME, DOB FROM EMPLOYEES", db);
        **QVariant**  v = query.result()->handle();
            if (v.isValid() &&
        qstrcmp(v.typeName(), "sqlite3_stmt*") == 0) {
                // v.data()
        returns a pointer to the handle
                sqlite3_stmt *handle =
        *static_cast<sqlite3_stmt *\\*>(v.data());
                if (handle) {
        // ...
                }
            }

        This snippet returns the handle for PostgreSQL or MySQL:

        if (qstrcmp(v.typeName(), "PGresult*") == 0) {
                PGresult *handle
        = *static_cast<PGresult *\\*>(v.data());
                if (handle) {
        // ...
                    }
            }

            if (qstrcmp(v.typeName(),
        "MYSQL_STMT*") == 0) {
                MYSQL_STMT *handle =
        *static_cast<MYSQL_STMT *\\*>(v.data());
                if (handle) {
        // ...
                    }
                }

        **See also** **QSqlDriver::handle** ().
        """
        ...
